TEST_MAZES = 0

   LIST OFF

   processor 6502

;;
;; NOTE: You must compile this with vcs.h version 105 or greater.
;;
TIA_BASE_READ_ADDRESS = $30         ; set the read address base so this runs on
                                    ; the real VCS and compiles to the exact
                                    ; ROM image

   include vcs.h
   include macro.h
   include speakjet.inc

;; Berzerk Diagonal Robot Firing Hack
;; originally by Dennis Debro
;; Updated 6/17/2008 by Kurt (Nukey Shay) Howe to allow 2 players / 256 mazes (currently 64)
;;=========================================================================
;; This Berzerk hack's to allow the robots to fire diagonally. The difficulty
;; setting for player 1 must be set to PRO to see this. I think the algorithm
;; could be tweaked a little better but it does work as is.
;;
;; Take a look at the subroutine DetermineToFireRobotMissile to see the changes
;; I made to allow this. I didn't comment the changes but you can do a compare
;; on my disassembly posted to [stella]. Here is the link
;; http://www.biglist.com/lists/stella/archives/200412/msg00090.html;
;; Sorry for the lack of change comments but this was a quick hack.
;;
;; The robot missle offset table has changed too for this hack. Take a look at
;; InitRobotMissileYOffset and InitRobotMissileXOffset.
;;
;; I also changed the number font graphics to look more like the arcade. I also
;; changed the color of the player and score to reflect the arcade colors. Evil
;; Otto's graphics have changed too to look more like the arcade.
;;
;; I'm releasing this for someone to pick up and finish. I lost interest in
;; this and thought someone could continue this.
;; Possible enhancements
;;  - Title screen similar to A8/5200
;;  - Voice via AtariVox
;;  - More mazes
;;  - Better diagonal firing algorithm
;; ***  B E R Z E R K  ***
;; Copyright 1982 Atari, Inc
;; Programmer: Dan Hitchens
;; Analyzed, labeled and commented
;;  by Dennis Debro
;; Last Update: December 29, 2004
;;
;; - Dan seems to use a form of .skipDraw which was developed by
;;   Thomas Jentzsch (see
;;   http://www.biglist.com/lists/stella/archives/200102/msg00282.html)
;;   It doesn't use illegal opcodes like the one referenced above. It looks
;;   more like my first attempt. Where two variables are used (upper and
;;   lower boundaries) to determine if it's time to draw the sprite.
;; - This game adjusts game speed so PAL and NTSC game speeds are virtually
;;   identical. Notice how the frame delay values for PAL are 1.2 times that
;;   of the NTSC values.
;; - It looks as if it was planned for the robots to fire diagonally. The
;;   values are present in the ROM but would need a little adjusting to get it
;;   accurate.
;; - Looks as if RAM locations $FA and $FB are not used
;; - Evil Otto is launched at ~12 seconds after entering a board
;; - A number flags and RAM overlays are used in this game so I may not have
;;   identified them all correctly.

   LIST ON

;===============================================================================
; A S S E M B L E R - S W I T C H E S
;===============================================================================

NTSC                    = 0
PAL                     = 1

COMPILE_VERSION         = NTSC     ; change this to compile for different
;COMPILE_VERSION         = PAL     ; change this to compile for different
                                    ; regions

;============================================================================
; T I A - C O N S T A N T S
;============================================================================

HMOVE_L7          =  $70
HMOVE_L6          =  $60
HMOVE_L5          =  $50
HMOVE_L4          =  $40
HMOVE_L3          =  $30
HMOVE_L2          =  $20
HMOVE_L1          =  $10
HMOVE_0           =  $00
HMOVE_R1          =  $F0
HMOVE_R2          =  $E0
HMOVE_R3          =  $D0
HMOVE_R4          =  $C0
HMOVE_R5          =  $B0
HMOVE_R6          =  $A0
HMOVE_R7          =  $90
HMOVE_R8          =  $80

; values for NUSIZx:
ONE_COPY          = %000
TWO_COPIES        = %001
TWO_WIDE_COPIES   = %010
THREE_COPIES      = %011
DOUBLE_SIZE       = %101
THREE_MED_COPIES  = %110
QUAD_SIZE         = %111
MSBL_SIZE1        = %000000
MSBL_SIZE2        = %010000
MSBL_SIZE4        = %100000
MSBL_SIZE8        = %110000

VERTICAL_DELAY    = 1

; values for REFPx:
NO_REFLECT        = %0000
REFLECT           = %1000

; SWCHA joystick bits:
MOVE_RIGHT        = %1000
MOVE_LEFT         = %0100
MOVE_DOWN         = %0010
MOVE_UP           = %0001
NO_MOVE           = %0000

; mask for SWCHB
BW_MASK           = %1000         ; black and white bit
SELECT_MASK       = %10
RESET_MASK        = %01

;============================================================================
; U S E R - C O N S T A N T S
;============================================================================

ROMTOP         = $F000

MAX_SCREENS    = %00111111 ; AND value for random screen selection
TOTAL_SCREENS  = 64

; color constants
BLACK          =  $00
WHITE          =  $0E

   IF COMPILE_VERSION = NTSC

;VBLANK_TIME    = $2C
;OVERSCAN_TIME  = $24
VBLANK_TIME    = $2D
OVERSCAN_TIME  = $25

; NTSC color constants
YELLOW         = $10
RED            = $30
RED_2          = $40
RED_3          = RED_2
RED_4          = RED
PURPLE         = $50
BLUE           = $88
GREEN_BLUE     = $A8
LT_GREEN       = $CA
BROWN          = $F0
BROWN_2        = BROWN
BLACK2         = $10

PLAYER_FRACTIONAL_DELAY    = $70    ; move 7 out of 16 frames

; Robot movement frame delay values
ROBOT_MOVE_DELAY_0         = $20    ; move 4 out of 32 frames
ROBOT_MOVE_DELAY_1         = $28    ; move 5 out of 32 frames
ROBOT_MOVE_DELAY_2         = $30    ; move 6 out of 32 frames
ROBOT_MOVE_DELAY_3         = $38    ; move 7 out of 32 frames
ROBOT_MOVE_DELAY_4         = $40    ; move 8 out of 32 frames
ROBOT_MOVE_DELAY_5         = $48    ; move 9 out of 32 frames
ROBOT_MOVE_DELAY_6         = $50    ; move 10 out of 32 frames
ROBOT_MOVE_DELAY_7         = $58    ; move 11 out of 32 frames

; Robot missile frame delay values
ROBOT_MISSILE_DELAY_0      = $38    ; move 7 out of 32 frames
ROBOT_MISSILE_DELAY_1      = $40    ; move 8 out of 32 frames
ROBOT_MISSILE_DELAY_2      = $50    ; move 10 out of 32 frames
ROBOT_MISSILE_DELAY_3      = $60    ; move 12 out of 32 frames
ROBOT_MISSILE_DELAY_4      = $78    ; move 15 out of 32 frames
ROBOT_MISSILE_DELAY_5      = $90    ; move 18 out of 32 frames
ROBOT_MISSILE_DELAY_6      = $B0    ; move 22 out of 32 frames
ROBOT_MISSILE_DELAY_7      = $D0    ; move 26 out of 32 frames

   ELSE

;VBLANK_TIME    = $36
;OVERSCAN_TIME  = $2B
VBLANK_TIME    = $37
OVERSCAN_TIME  = $2B

; PAL color constants
BLACK2         = $10
YELLOW         = $20
BROWN          = $40
RED            = $60
RED_2          = RED
RED_3          = BROWN
RED_4          = RED_3
GREEN_BLUE     = $56
LT_GREEN       = $5E
PURPLE         = $A0
BLUE           = $DA
BROWN_2        = $F0

PLAYER_FRACTIONAL_DELAY    = $86    ; move 7 out of 16 frames

; Robot movement frame delay values
ROBOT_MOVE_DELAY_0         = $26    ; move 4 out of 32 frames
ROBOT_MOVE_DELAY_1         = $30    ; move 5 out of 32 frames
ROBOT_MOVE_DELAY_2         = $3A    ; move 6 out of 32 frames
ROBOT_MOVE_DELAY_3         = $43    ; move 7 out of 32 frames
ROBOT_MOVE_DELAY_4         = $4D    ; move 8 out of 32 frames
ROBOT_MOVE_DELAY_5         = $56    ; move 9 out of 32 frames
ROBOT_MOVE_DELAY_6         = $60    ; move 10 out of 32 frames
ROBOT_MOVE_DELAY_7         = $6A    ; move 11 out of 32 frames

; Robot missile frame delay values
ROBOT_MISSILE_DELAY_0      = $43    ; move 7 out of 32 frames
ROBOT_MISSILE_DELAY_1      = $4D    ; move 8 out of 32 frames
ROBOT_MISSILE_DELAY_2      = $60    ; move 10 out of 32 frames
ROBOT_MISSILE_DELAY_3      = $73    ; move 12 out of 32 frames
ROBOT_MISSILE_DELAY_4      = $90    ; move 15 out of 32 frames
ROBOT_MISSILE_DELAY_5      = $AD    ; move 18 out of 32 frames
ROBOT_MISSILE_DELAY_6      = $D3    ; move 22 out of 32 frames
ROBOT_MISSILE_DELAY_7      = $FA    ; move 26 out of 32 frames

   ENDIF

COLOR_LIGHT_LUM            = $F7

;note: these 2 must not have low bit set!
PLAYER_COLOR               = LT_GREEN-2
PLAYER2_COLOR              = YELLOW+12

H_FONT                     = 7
H_ROBOT                    = 9
H_PLAYER                   = 12

H_KERNEL                   = 176

XMIN                       = 0
XMAX                       = 149
XMAX_PLAYER                = XMAX - 3

YMIN                       = 0

;MAX_GAME_SELECTION         = $12    ; BCD
MAX_GAME_SELECTION         = 24

SELECT_DELAY               = 26

MAX_ROBOTS                 = 8

INIT_NUM_LIVES             = 3

SHOOTING_ROBOT_SCORE       = $50    ; BCD

ROBOT_STAND_ANIM_OFFSET    = 0
ROBOT_LEFT_ANIM_OFFSET     = 9
ROBOT_RIGHT_ANIM_OFFSET    = 12
ROBOT_UP_ANIM_OFFSET       = 15
ROBOT_DOWN_ANIM_OFFSET     = 19
ROBOT_DEATH_ANIM_OFFSET    = 23

PLAYER_STAND_ANIM_OFFSET   = 0
PLAYER_RUN_ANIM_OFFSET     = 1
PLAYER_DEATH_ANIM_OFFSET   = 3

; game variation flags
OTTO_INVINCIBLE            = %00100000
OTTO_REBOUND               = %00010000
NON_SHOOTING               = %00001000
EXTRA_LIFE_2000            = %00000100
EXTRA_LIFE_1000            = %00000010

; player starting location values
PLAYER_ENTERING_NORTH      = 0
PLAYER_ENTERING_SOUTH      = 1
PLAYER_ENTERING_WEST       = 2
PLAYER_ENTERING_EAST       = 3

ROBOT_SHOOTING_RIGHT       = %0001
ROBOT_SHOOTING_LEFT        = %0010
ROBOT_SHOOTING_DOWN        = %0100
ROBOT_SHOOTING_UP          = %1000

XROBOT_MISSILE_BOX         = 32;8
YROBOT_MISSILE_BOX         = 24;6


;============================================================================
; M A C R O S
;============================================================================
;
; time wasting macros
;

   MAC SLEEP_3
      sta $2E
   ENDM

   MAC SLEEP_4
      nop
      nop
   ENDM

   MAC SLEEP_5
      dec $2E
   ENDM

   MAC SLEEP_6
      lda ($00,x)
   ENDM

   MAC SLEEP_8
      SLEEP_6
      nop
   ENDM

   MAC SLEEP_7
      dec $2E
      nop
   ENDM

   MAC SLEEP_9
      SLEEP_7
      nop
   ENDM

;============================================================================
; Z P - V A R I A B L E S
;============================================================================

   SEG.U Ram
   org  $80

gameSelection            DS 1 ;$80
gameState                DS 1 ;$81
mazeNumber               DS 1 ;$82
console                  DS 1 ;$83         ; use for autodetect instead
mazePF0Value             = console         ; (high nybble used for door info)

frameCount               DS 1 ;$84

speech_addr              DS 2 ; VOX speech data pointer

START_GAME_RAM           DS 1 ;$85
;--------------------------------------
colorEOR                = START_GAME_RAM
Marquee                 = colorEOR

evilOttoLaunchTimer      DS 1 ;$EF



playerGraphicPointer     DS 2 ;$89       ; $89 - $8A
playerVertPos            DS 1 ;$8B
player0Scanline          DS 1 ;$8C
playerUpperBoundary      DS 1 ;$8D
playerDirection          DS 1 ;$8E
playerMissilePointer     DS 2 ;$8F       ; $8F - $90
playerAnimationIndex     DS 1 ;$91
playerMotion             DS 1 ;$92       ; fractional delay for player movement
playerHorizPos           DS 1 ;$93
playerMissileFlightTime  DS 1 ;$94
playerMissileDirection   DS 1 ;$95
playerMissileHorizPos    DS 1 ;$96
playerMissileVertPos     DS 1 ;$97
robotMissilePointer      DS 2 ;$98       ; $98 - $99
robotMissileDirection    DS 1 ;$9A
robotMissileDelay        DS 1 ;$9B       ; fractional delay value for missile
robotMissileFlightTime   DS 1 ;$9C
robotMissileHorizPos     DS 1 ;$9D
robotMissileVertPos      DS 1 ;$9E

delayRobotAnimation      DS MAX_ROBOTS ;$9F
;--------------------------------------
robotFineHoriz          = delayRobotAnimation   ; $9F - $A6
;--------------------------------------
upperPlayfieldLimit     = delayRobotAnimation+MAX_ROBOTS-1 ; upper scan.limit for screen trans.
robotCoarseHoriz         DS MAX_ROBOTS ;$A7             ; $A7 - $AE
evilOttoHorizPos        = robotCoarseHoriz+MAX_ROBOTS-1    ;$AE
robotPointers            DS MAX_ROBOTS ;$AF       ; $AF - $B6
robotMotion              DS 1 ;$B7       ; fractional delay for robot movement
robotVertPos             DS MAX_ROBOTS+1 ;$B8       ; $B8 - $C0 ??
robotHorizPos            DS MAX_ROBOTS ;$C1       ; $C1 - $C8
;--------------------------------------
tempOttoVertPos         = robotHorizPos+MAX_ROBOTS-1 ; $C8
playerCollisions         DS MAX_ROBOTS ;$C9       ; $C9 - $D0
;--------------------------------------
lowerPlayfieldLimit     = playerCollisions+MAX_ROBOTS-1 ;$D0;lower scan.limit for screen trans.
prevEvilOttoVertPos      DS 1 ;$D1
robotAnimationIndex      DS MAX_ROBOTS ;$D2       ; $D2 - $D9
evilOttoVertPos         = robotAnimationIndex+MAX_ROBOTS-1 ;$D9

robotMotionDelay         DS 1 ;$E0


PlayerNumber             DS 1 ;$DD       ; $DD - $DF
temp03                  = PlayerNumber
numberRobotsKilled       DS 1 ;$DB

;next 12 bytes to be consecutive...
playerinfo               DS 12
numberOfLives           = playerinfo    ;$DA
playerScore             = playerinfo+2  ;$DD       ; $DD - $DF
gameLevel               = playerinfo+8  ;$DC       ; incremented when level is completed
playerStartingLocation  = playerinfo+10 ;$E2



random                   DS 2 ;$E3       ; $E3 - $E4



;digitPointer            = $EA          ; $EA - $F5
;evilOttoLaunchTimer     = $F6
;audioIndex              = $F7
;robotMissileSoundIndex  = $F8
;ottoVerticalDelta       = $F9
;kernelSection           = $FC
;playerGraphicLSB        = $FD
;;--------------------------------------
;player0Graphic          = playerGraphicLSB
;robotCoarsePos          = $FE       ; value to coarse move robot in kernel

audioIndex               DS 1 ;$F0
robotMissileSoundIndex   DS 1 ;$F1
ottoVerticalDelta        DS 1 ;$F2


initRobotDelay           DS 1 ;$E5       ; robots not active until value is 255

temp01                   DS 1 ;$E6
;--------------------------------------
lsbDigitPointer         = temp01
;--------------------------------------
robotGraphics           = lsbDigitPointer
;--------------------------------------
tempPlayerExitingPos    = robotGraphics



selectDebounce           DS 1 ;$86
attractModeTimer         DS 1 ;$87

;;gameVariation           = $88

loopCount                DS 1 ;$E8
;--------------------------------------
randomNumberMax         = loopCount
lastRobotVertPos         DS 1 ;$E9
;--------------------------------------
tempCharHolder          = lastRobotVertPos
;--------------------------------------
compRobotToMove         = tempCharHolder

digitPointer             DS 12 ;$F4          ; $F4 - $FF
;indirect pointers now shared to also display maze GFX (which can be set to any page)
mazePFpointer = digitPointer
saveYregister = digitPointer+6 ;used while implementing the change
gameVariation  = saveYregister

playerGraphicLSB    = digitPointer+7    ;was $F3
;--------------------------------------
player0Graphic          = playerGraphicLSB

temp02        = digitPointer+8 ;$E7       ; used for various things

MaxTries      = digitPointer+9
LineCount     = MaxTries

kernelSection = digitPointer+10

robotCoarsePos = digitPointer+11    ; value to coarse move robot in kernel

  IF digitPointer = $F4
    ECHO "RAM OK"
  ENDIF

;============================================================================
; R O M - C O D E (Part 1)
;============================================================================

   SEG Bank0
   org  $1000
   rorg $D000

ReturnToBank2
   bit $1FF9

   lda gameState                    ; get the current game state
   bpl RegularScreen
   jmp DisplayLivesKernel

RegularScreen:
;-------------------------
   lda colorEOR
   bne DisplayKernel
   lda initRobotDelay
   cmp #$FF
   beq DetermineRobotColor
;;   ldx #$00
   stx COLUP0                       ; set player's color to BLACK
   jmp .setRobotColor               ; could use unconditional branch

DetermineRobotColor
   lda gameLevel                    ; get the current game level
   lsr                              ; divide value by 2
   and #7                           ; make value 0 <= x <= 7
   tax                              ; move to x for robot color lookup
   lda RobotColorTableBank0,x       ; get the color for robots
.setRobotColor
      sta COLUP1

   IF COMPILE_VERSION = NTSC

DisplayKernel SUBROUTINE
      lda #%11100000
      sta PF0
      lda #%11111111
      sta PF1
      ldx playerStartingLocation       ; get the player's starting location
      lda jp_top_table,x
.setMazePF2Value
      sta PF2
      lda #$30
      sta HMBL
      sta WSYNC
      sta RESBL
.waitTime
      lda INTIM
      bne .waitTime
      sta WSYNC                        ; wait for next scan line
      sta HMOVE
      sta WSYNC
      sta VBLANK                       ; enable TIA (D1 = 0)
      sta WSYNC
      sta HMCLR                        ; clear all horizontal motions
      sta CXCLR                        ; clear all collisions

   ELSE

      lda #$30
      sta HMBL
      sta WSYNC
      sta RESBL
DisplayKernel SUBROUTINE
.waitTime
      lda INTIM
      bne .waitTime
      sta WSYNC
      sta HMOVE
      sta VBLANK
      ldx #22
.skip22Scanlines
      sta WSYNC
      dex
      bne .skip22Scanlines

      lda #%11100000
      sta PF0
      lda #%11111111
      sta PF1
      ldx playerStartingLocation       ; get the player's starting location
      lda jp_top_table,x
.setMazePF2Value
      sta PF2

      sta HMCLR                        ; clear all horizontal motions
      sta CXCLR                        ; clear all collisions

   ENDIF


   ldy #2
   cpy player0Scanline
   bcc .skipPlayerGraphicSet
   lda (playerGraphicPointer),y
   sta player0Graphic
.skipPlayerGraphicSet
;use 7800-compatable switch for closed doors...
   lda console ;bit 2 = enable
   and #%00000100
   beq SkipBall
   lda jp_ball_table,x
SkipBall:
   sta HMBL
   iny
   sta WSYNC
   sta HMOVE
   sta ENABL ;moved down here to remove small artifacts at the top of the screen
   sta WSYNC
   sta HMCLR
   jmp JumpIntoGameKernel2

.waste15Cycles
   SLEEP_5
.waste10Cycles
   nop
   clc
   bcc .drawMazeData          ; 2

ReadCollisionsForSection
   lda CXP1FB                 ; 3         read player1/PF collision
   ora CXM0P                  ; 3         or player0 missile collisions
   ora CXPPMM                 ; 3         or player/player and 
   and #%10000000             ; 2         mask ball, M0/M0, M0/P0 collisions
   bit CXM1P                  ; 3
   bvc .setCollisions         ; 2
   ora #1                     ; 2         show a robot shot this robot
.setCollisions
   sta playerCollisions,x     ; 4
   sta WSYNC
;--------------------------------------
   SLEEP_3                    ; 3 HMOVE in alternate
   lda player0Graphic         ; 3
   sta GRP0                   ; 3 = @09
   lda (playerMissilePointer),y; 5
   sta ENAM0                  ; 3 = @17
   cpy player0Scanline        ; 3 = @28
   bcc .waste15Cycles         ; 2
   cpy playerUpperBoundary    ; 3
   bcs .waste10Cycles         ; 2
   lda (playerGraphicPointer),y; 5
   sta player0Graphic         ; 3
.drawMazeData
   iny                        ; 2 replacement = 0
   sty saveYregister          ; 3
   tya                        ; 2
   lsr                        ; 2
   tay                        ; 2
   lda mazePF0Value           ; 3
   and #%00100000             ; 2
   ora (mazePFpointer),y      ; 5
   tax                        ; 2
   lda (mazePFpointer+4),y    ; 5
   sta PF2                    ; 3
   lda (mazePFpointer+2),y    ; 5
   sta PF1                    ; 3 replacement = @37
;--------------------------------------
   stx PF0                    ; 3 = @04
   ldy saveYregister          ; 3
   lda robotGraphics          ; 3
   sta GRP1                   ; 3 = @10   draw Robot
   ldx robotCoarsePos         ; 3
   bmi CoarseMoveRobotOnRight ; 2
   SLEEP_3                    ; 3
.coarseMoveRobot
   dex                        ; 2
   bpl .coarseMoveRobot       ; 2
   sta RESP1                  ; 3
   lda (robotMissilePointer),y; 5
   sta ENAM1                  ; 3
   ldx kernelSection          ; 3
   lda robotPointers,x        ; 4
   tax                        ; 2
   lda RobotGraphics,x        ; 4
   sta robotGraphics          ; 3
   jmp NextRobotKernelSection ; 3

CoarseMoveRobotOnRight SUBROUTINE
   lda (robotMissilePointer),y; 5
   sta ENAM1                  ; 3 = @24
   ldx kernelSection          ; 3
   lda robotPointers,x        ; 4
   tax                        ; 2
   lda RobotGraphics,x        ; 4
   sta robotGraphics          ; 3
   ldx robotCoarsePos         ; 3 = @43
.coarseMoveRobot
   inx                        ; 2
   bmi .coarseMoveRobot       ; 2
   sta RESP1                  ; 3
NextRobotKernelSection
   sta WSYNC
;--------------------------------------
   sta HMOVE                  ; 3
JumpIntoGameKernel2
   lda player0Graphic         ; 3
   sta GRP0                   ; 3 = @09
   lda (playerMissilePointer),y; 5
   sta ENAM0                  ; 3 = @17
   cpy player0Scanline        ; 3 = @28
   bcc .waste12Cycles         ; 2+1
   cpy playerUpperBoundary    ; 3
   bcs .waste7Cycles          ; 2+1
   lda (playerGraphicPointer),y; 5
   sta player0Graphic         ; 3
.drawMazeData
   iny                        ; 2 replacement = 0
   sty saveYregister          ; 3
   tya                        ; 2
   lsr                        ; 2
   tay                        ; 2
   lda mazePF0Value           ; 3
   and #%00100000             ; 2
   ora (mazePFpointer),y      ; 5
   tax                        ; 2
   lda (mazePFpointer+4),y    ; 5
   sta PF2                    ; 3
   lda (mazePFpointer+2),y    ; 5
   sta PF1                    ; 3 replacement = @37
;--------------------------------------
   stx PF0                    ; 3 = @04
   ldy saveYregister          ; 3
   lda robotGraphics          ; 3
   sta GRP1                   ; 3 = @10
   lda (robotMissilePointer),y; 5
   sta ENAM1                  ; 3 = @18
   ldx kernelSection          ; 3
   tya                        ; 2
   cmp robotVertPos,x         ; 4
   bne DoneRobotKernelSection ; 2
   lda robotFineHoriz,x       ; 4
   sta HMP1                   ; 3 = @36
   lda robotCoarseHoriz,x     ; 4
   sta robotCoarsePos         ; 3
   lda #0                     ; 2
   sta robotGraphics          ; 3
   jmp ReadCollisionsForSection; 3

DoneRobotKernelSection
   bcc .skipRobotDraw         ; 2
   sec                        ; 2         not needed -- carry already set
   sbc #MAX_ROBOTS+1          ; 2
   bmi .drawNextRobotLine     ; 2
   cmp robotVertPos,x         ; 4
   bcc .drawNextRobotLine     ; 2
   inc kernelSection          ; 5
.drawNextRobotLine
   inc robotPointers,x        ; 6         increment robot pointer offset
   lda robotPointers,x        ; 4         to draw next robot line
   tax                        ; 2
   lda RobotGraphics,x        ; 4
.setRobotGraphics
   sta robotGraphics          ; 3
   sta WSYNC
;--------------------------------------
   jmp JumpIntoGameKernel2    ; 3

.skipRobotDraw
   cpy #(H_KERNEL / 2) - 1    ; 2
   bcs LastKernelSection      ; 2+1
   lda #0                     ; 2
   beq .setRobotGraphics      ; 2 always branch

.waste12Cycles
   SLEEP_5
.waste7Cycles
   SLEEP_3                    ; 3
   jmp .drawMazeData          ; 3

LastKernelSection
   sta WSYNC
;--------------------------------------
   lda player0Graphic         ; 3
   sta GRP0                   ; 3 = @06
   lda (playerMissilePointer),y;5
   sta ENAM0                  ; 3 = @14
   cpy playerUpperBoundary    ; 3
   bcs .skipPlayerGraphicSetB ; 2
   lda (playerGraphicPointer),y;5
   sta player0Graphic         ; 3
.skipPlayerGraphicSetB
   sta WSYNC
;--------------------------------------
   lda #%11100000             ; 2
  sta ENABL  ; &*&*&*
   sta PF0                    ; 3 = @05
   lda #%11111111             ; 2
   sta PF1                    ; 3 = @10
   ldx playerStartingLocation ; 3
   lda jp_bottom_table,x
.setPF2ForNextScanline
   sta PF2                    ; 3 = @24
   sta WSYNC
;--------------------------------------
   lda player0Graphic         ; 3
   sta GRP0                   ; 3 = @06
   ldx #0                     ; 2
   stx GRP1                   ; 3 = @11
   sta WSYNC
;--------------------------------------
   stx GRP1                   ; 3 = @03
   stx GRP0                   ; 3 = @06
   sta WSYNC
;--------------------------------------
   lda CXP1FB                 ; 3         read player1/PF collision
   ora CXM0P                  ; 3         or player0 missile collisions
   ora CXPPMM                 ; 3         or player/player and 
   and #%10000000             ; 2         mask ball, M0/M0, M0/P0 collisions
   bit CXM1P                  ; 3
;clear playfield GFX
   stx PF0
   stx PF1
   stx PF2
   bvc .setCollisions         ; 2
   ora #1                     ; 2         show a robot shot this robot
.setCollisions
   ldx kernelSection          ; 3
   sta playerCollisions,x     ; 4
Clear_Digits:
   ldx #12
   lda #<Blank
   ldy #>Blank
.blankScoreGraphicsLoop ;OK to use now
   sta digitPointer-2,x
   sty digitPointer-1,x
   dex
   dex
   bne .blankScoreGraphicsLoop


CheckToShowLevelBonus
   lda robotVertPos                 ; get the robot's vertical position
   cmp #$7F
   bne BCDToDigits                  ; branch if not all robots shot
;moved lower to take add'l scanline in copyright screen
   lda numberOfLives                ; get the number of lives remaining
   cmp #%11111111
   beq BCDToDigits                  ; if negative -- game over
   lda #<zero
   sta digitPointer+2               ; point to zero sprite
   lda numberRobotsKilled           ; get number of robots killed this round
   asl
   asl
   asl
   sta digitPointer
   sta WSYNC
Dont_Display_Number_Of_Lives:
   sta WSYNC
   sta WSYNC
   jmp LivesKernelEnd         ; 3


;blank loop takes up the slack
.skipRestDigits2
   dec $2E
.skipRestDigits
   dec $2E
   inx
   inx
   cpx #10
   bcc .skipRestDigits2
   bcs ScoreKernel



No_Otto_For_Text ;waste 9
   nop                        ; 2
   .byte $2C                  ; 4
Use_Steady_Otto_Icon ;waste 3
   ldy #<OttoGames            ; 2
   sta $2E                    ; 3
   jmp Set_Otto_Icon          ; 3

BCDToDigits
   ldy #4
   ldx #11
   lda playerScore+4                ;
   cmp #$FF
   bne .bcdToDigitsLoop             ; skip if game selection # shown (and show score)

;display game selection text...
   tsx                        ; 2
   txa                        ; 2
   ldy #<Blank                ; 2
   and #OTTO_INVINCIBLE|OTTO_REBOUND ; 2
   beq No_Otto_For_Text       ; 2
   and #OTTO_INVINCIBLE       ; 2
   bne Use_Steady_Otto_Icon   ; 2
   lda frameCount             ; 3
   and #8                     ; 2
   beq Set_Otto_Icon          ; 2
   ldy #<OttoGames            ; 2
Set_Otto_Icon
   sty digitPointer+10              ; store otto icon (if present)


   lda gameSelection          ; 3
   and #1                     ; 2
   tay                        ; 2
   lda LivesIcons,y           ; 4
   sta digitPointer+4         ; 2 store # player icon

   txa                        ; 2
   lsr                        ; 2
   tax                        ; 2
   and #3                     ; 2
   tay                        ; 2
   lda BonusIcons,y           ; 4
   sta digitPointer+6         ; 2 store bonus icon

   txa                        ; 2
   lsr                        ; 2
   lsr                        ; 2
;   tax                        ; 2
   and #1                     ; 2
   tay                        ; 2
   lda ShootIcons,y           ; 4
   sta digitPointer+8         ; 2 store shooting icon


   IF COMPILE_VERSION = NTSC

   lda #$30

   ELSE

   lda #$40

   ENDIF

   sta temp03                 ; reset color to display game selection
   ldx #3                     ; reset pointers to only translate 1 variable
   ldy #0

.bcdToDigitsLoop
   lda playerScore,y                ; get the player's score
Display_Number_Of_Lives2:
   sta digitPointer                 ; store it in the graphics pointer
   and #$0F                         ; mask the upper nybbles and move it to x
   asl
   asl
   asl
   sta digitPointer-1,x             ; store it in the graphics pointer
   lda digitPointer                 ; store it in the graphics pointer
   and #$F0                         ; mask the lower nybbles
   lsr                              ; move upper nybble to lower nybble
   sta digitPointer-3,x             ; store it in the graphics pointer
   dey
   dey
   dex                              ;
   dex                              ;
   dex                              ;
   dex                              ;
   bpl .bcdToDigitsLoop
   inx                              ;
   ldy #<Blank                      ; if one is found then set the LSB to
.suppressZeroLoop
   lda digitPointer,x               ; cycle through the digit pointers to
   cmp #<zero                       ; find one that points to zero (starting
   bne .skipRestDigits              ; from the 1st pointer)
   sty digitPointer,x               ; point to the space
   inx
   inx
   cpx #10
   bcc .suppressZeroLoop


.skipBCDToDigits
LivesKernelEnd
ScoreKernel
   sta WSYNC
;--------------------------------------
   lda #0                     ; 2
   sta REFP0                  ; 3 = @5
   sta HMP1                   ; 3 = @8

   lda #HMOVE_R1              ; 2
   sta HMP0                   ; 3 = @13   player 0 @ pixel 118

   lda #THREE_COPIES          ; 2
   sta NUSIZ0                 ; 3 = @18
   sta NUSIZ1                 ; 3 = @21
   ldx #VERTICAL_DELAY        ; 2
   stx VDELP0                 ; 3
   stx VDELP1                 ; 3
   nop                        ; 2 = @31

   IF COMPILE_VERSION = NTSC

   lda #$84

   ELSE

   lda #$D4

   ENDIF

   bit selectDebounce         ; 3 get select debounce flag
   sta RESP0                  ; 3 = @39
   sta RESP1                  ; 3 = @42   player 1 @ pixel 126
   bne GameSelectColor        ; 2

   lda temp03                 ; 3 = @47
   bne SkipGameSelectColor    ; 2 = @50
GameSelectColor:
   dec $2E                    ; 5 = @50
SkipGameSelectColor:
   eor colorEOR               ; 3 = @53
   sta COLUP0                 ; 3 = @56
   sta.w COLUP1               ; 4 = @60
   ldy #H_FONT                ; 2 = @62
.drawLoop
   dey                        ; 2 = @64
   sty loopCount              ; 3 = @67
   lda (digitPointer),y       ; 5 = @72
   sta GRP0                   ; 4 = @75
;--------------------------------------
   sta HMOVE                  ; 2 (1 before new scanline)
   lda (digitPointer+2),y     ; 5 = @07
   sta GRP1                   ; 3 = @10
   lda (digitPointer+4),y     ; 5
   sta GRP0                   ; 3 = @18
   lda (digitPointer+6),y     ; 5
   sta tempCharHolder         ; 3
   lax (digitPointer+8),y     ; 5 ILLEGAL!
   lda (digitPointer+10),y    ; 5
   tay                        ; 2
   lda tempCharHolder         ; 3
   sta GRP1                   ; 3 = @44
   stx GRP0                   ; 3 = @47
   sty GRP1                   ; 3 = @50
   sta GRP0                   ; 3 = @53

   sta HMCLR                  ; 3 = @56

   ldy loopCount              ; 3
   bne .drawLoop              ; 2
   sty GRP0                   ; 3 = @64
   sty GRP1                   ; 3 = @67
   sty GRP0                   ; 3 = @70
   sty NUSIZ0                 ; 3 = @73
   sty NUSIZ1                 ; 3 = @76
;--------------------------------------
   jmp ReturnToBank2





DisplayLivesKernel SUBROUTINE
; NOTE: we are still in vertical blank here...
      lda #0

   IF COMPILE_VERSION = NTSC
      sta PF0                          ; clear playfield registers
      sta PF1
      sta PF2
   ENDIF

   sta AUDV0                        ; turn off audio volume
   ldx audioIndex
   beq .waitTime
   lda frameCount                   ; get the current frame count
   and #$07                         ; update the frequency every 8 frames
   bne .skipSetAudioFrequency
   lda AudioFrequencyTable,x
   sta AUDF0
   dec audioIndex
.skipSetAudioFrequency
   lda #13
   sta AUDC0
   lda #13                          ; load accumulator with 13 again ???
   sta AUDV0
.waitTime
   ldx INTIM
   bne .waitTime
   
   IF COMPILE_VERSION = NTSC

      stx WSYNC
      stx VBLANK                       ; enable TIA (D1 = 0)

   ELSE

      stx VBLANK                       ; enable TIA (D1 = 0)
      ldx #21
.skip22Scanlines
      sta WSYNC
      dex
      bne .skip22Scanlines

   ENDIF

   lda upperPlayfieldLimit
   beq DrawUpperPlayfieldBoarder
ClearUpperPlayfield
   sta WSYNC
;--------------------------------------
   lda #0                     ; 2
   sta PF0                    ; 3 = @05   clear playfield registers
   sta PF1                    ; 3 = @08   draw upper for center clear, all for top clear
   sta PF2                    ; 3 = @11
   sta WSYNC
;--------------------------------------
   inx                        ; 2
   cpx upperPlayfieldLimit    ; 3
   bne ClearUpperPlayfield    ; 2
DrawUpperPlayfieldBoarder
   cpx lowerPlayfieldLimit    ; 3
   beq ClearLowerPlayfield    ; 2
   cpx #2                     ; 2
   bcs DrawShrinkingPlayfield ; 2
   sta WSYNC
;--------------------------------------
   lda #%11100000             ; 2
   sta PF0                    ; 3 = @05
   lda #%11111111             ; 2
   sta PF1                    ; 3 = @10
   lda #%00000111             ; 2
   sta PF2                    ; 3 = @15
   inx                        ; 2
   sta WSYNC
;--------------------------------------
   bne DrawUpperPlayfieldBoarder; 3         could use unconditional branch

DrawShrinkingPlayfield
   cpx #86                    ; 2
   bcs DrawLowerPlayfieldBoarder; 2
   sta WSYNC
;--------------------------------------
   txa                        ; 2
   lsr                        ; 2
   tay                        ; 2
   iny                        ; 2
   lda (mazePFpointer),y      ; 5
   sta PF0                    ; 3
   lda (mazePFpointer+2),y    ; 5
   sta PF1                    ; 3
   lda (mazePFpointer+4),y    ; 5

.jumpIntoShrinkingPF
   sta PF2                    ; 3 = @32
   inx                        ; 2
   sta WSYNC
;--------------------------------------
   cpx lowerPlayfieldLimit    ; 3
   bne DrawShrinkingPlayfield ; 2
ClearLowerPlayfield
   lda #0                     ; 2
   cpx #(H_KERNEL / 2)        ; 2
   beq .jumpToScoreKernel     ; 2
   sta WSYNC
;-------------------------------------- draw lower for center clear/all for lower clear
   sta PF0                    ; 3
   sta PF1                    ; 3
   sta PF2                    ; 3
   sta WSYNC
;--------------------------------------
   inx                        ; 2
   bne ClearLowerPlayfield    ; 3         could use unconditional branch

.jumpToScoreKernel
;   sta WSYNC
;-------------------------
   sta PF0
   sta PF1
   sta PF2
   ldx #12
   lda #<Blank
   ldy #>Blank
.blankLivesGraphicsLoop
   sta digitPointer-2,x
   sty digitPointer-1,x
   dex
   dex
   bne .blankLivesGraphicsLoop
   lda #<LivesIndicator
   ldy numberOfLives
   jmp .jumpToLivesKernel

DrawLowerPlayfieldBoarder
   sta WSYNC
;--------------------------------------
   lda #%11100000             ; 2
   sta PF0                    ; 3 = @05
   lda #%11111111             ; 2
   sta PF1                    ; 3 = @10
   lda #%00000111             ; 2
   bne .jumpIntoShrinkingPF   ; 3         could use unconditional branch




;2k of free space for mazes! :)
;Data is fully-relocatable and sharable.  Take care to place each 42-byte data table at least
;2 bytes from a page break, tho (those bytes can be used for other tables if you wish).  All
;data here has been "unshared" to allow easy editing.
;You can fit a -minimum- of 2 full screens in each page (6 tables each)
;current extra space used for version date:
   IF COMPILE_VERSION = NTSC
   org  $138B
   rorg $D38B
   .byte "By Kurt (Nukey Shay) Howe 6/17/2008"
   ELSE
   org  $138D
   rorg $D38D
   .byte "By Kurt (Nukey Shay) Howe 6/17/08"
   ENDIF



   org  $18D6,0
   rorg $D8D6,0

MazePF2Data_61
MazePF2Data_62
MazePF2Data_63
MazePF2Data_64
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|

   org  $1900,0
   rorg $D900,0

;skip past page break...free space
   .byte $00 ; |........|
   .byte $00 ; |........|

;double door w/stub barriers
MazePF0Data_19
MazePF0Data_48
MazePF0Data_49
MazePF0Data_50
MazePF0Data_51
MazePF0Data_52
MazePF0Data_53
MazePF0Data_54
MazePF0Data_55
MazePF0Data_56
MazePF0Data_57
MazePF0Data_58
MazePF0Data_59
MazePF0Data_60
MazePF0Data_64
   .byte $20 ; |..X.....|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
MazePF1Data_19
MazePF1Data_34
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
MazePF2Data_19
MazePF2Data_34
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
MazePF2Data_12
MazePF2Data_29
MazePF2Data_43
MazePF2Data_56
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $FF ; |XXXXXXXX|
   .byte $FF ; |XXXXXXXX|
MazePF2Data_16
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
MazePF2Data_13
MazePF2Data_30
MazePF2Data_44
MazePF2Data_57
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $FF ; |XXXXXXXX|
   .byte $FF ; |XXXXXXXX|
MazePF1Data_6
MazePF1Data_24
MazePF1Data_38
MazePF1Data_51
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $0F ; |....XXXX|
   .byte $0F ; |....XXXX|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
MazePF1Data_8
MazePF1Data_26
MazePF1Data_40
MazePF1Data_53
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $0F ; |....XXXX|
   .byte $0F ; |....XXXX|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|

   org  $1A00
   rorg $DA00

;skip 2 bytes past page break...
ShootIcons
   .byte <MissileGames
   .byte <Blank

MazePF0Data_21
MazePF0Data_22
MazePF0Data_23
MazePF0Data_24
MazePF0Data_25
MazePF0Data_26
MazePF0Data_27
MazePF0Data_28
MazePF0Data_29
MazePF0Data_30
MazePF0Data_31
MazePF0Data_32
MazePF0Data_33
MazePF0Data_34
MazePF0Data_63
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
MazePF0Data_5
MazePF0Data_18
MazePF0Data_35
MazePF0Data_36
MazePF0Data_37
MazePF0Data_38
MazePF0Data_39
MazePF0Data_40
MazePF0Data_41
MazePF0Data_42
MazePF0Data_43
MazePF0Data_44
MazePF0Data_45
MazePF0Data_46
MazePF0Data_61
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $00 ; |........|
MazePF2Data_10
MazePF2Data_28
MazePF2Data_42
MazePF2Data_55
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $FF ; |XXXXXXXX|
   .byte $FF ; |XXXXXXXX|
MazePF1Data_10
MazePF1Data_28
MazePF1Data_42
MazePF1Data_55
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $0F ; |....XXXX|
   .byte $0F ; |....XXXX|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
MazePF1Data_9
MazePF1Data_27
MazePF1Data_41
MazePF1Data_54
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $0F ; |....XXXX|
   .byte $0F ; |....XXXX|
MazePF1Data_12
MazePF1Data_29
MazePF1Data_43
MazePF1Data_56
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
MazePF1Data_15
MazePF1Data_32
MazePF1Data_46
MazePF1Data_59
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $1F ; |...XXXXX| shared
   .byte $1F ; |...XXXXX| shared
   .byte $10 ; |...X....| shared
   .byte $10 ; |...X....| shared
   .byte $10 ; |...X....| shared
   .byte $10 ; |...X....| shared
   .byte $10 ; |...X....| shared
   .byte $10 ; |...X....| shared
   .byte $10 ; |...X....| shared
   .byte $10 ; |...X....| shared
   .byte $10 ; |...X....| shared
   .byte $10 ; |...X....| shared
MazePF1Data_13
MazePF1Data_30
MazePF1Data_44
MazePF1Data_57
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
MazePF1Data_14
MazePF1Data_31
MazePF1Data_45
MazePF1Data_58
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $10 ; |...X....| shared
   .byte $10 ; |...X....| shared
   .byte $10 ; |...X....| shared
   .byte $10 ; |...X....| shared
   .byte $10 ; |...X....| shared
   .byte $10 ; |...X....| shared
   .byte $10 ; |...X....| shared
   .byte $10 ; |...X....| shared
   .byte $10 ; |...X....| shared
   .byte $10 ; |...X....| shared
   .byte $1F ; |...XXXXX| shared
   .byte $1F ; |...XXXXX| shared
MazePF1Data_18
MazePF1Data_33
MazePF1Data_47
MazePF1Data_60
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $07 ; |.....XXX|
   .byte $07 ; |.....XXX|
MazePF2Data_14
MazePF2Data_31
MazePF2Data_45
MazePF2Data_58
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $FF ; |XXXXXXXX|
   .byte $FF ; |XXXXXXXX|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|

   org  $1B00
   rorg $DB00

;skip 2 bytes past page break...
LivesIcons
   .byte <LivesIndicator2
   .byte <LivesIndicator

MazePF2Data_18
MazePF2Data_33
MazePF2Data_47
MazePF2Data_60
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $04 ; |.....X..|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
MazePF2Data_17
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $FF ; |XXXXXXXX| shared
   .byte $FF ; |XXXXXXXX| shared
   .byte $80 ; |X.......| shared
   .byte $80 ; |X.......| shared
   .byte $80 ; |X.......| shared
   .byte $80 ; |X.......| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
MazePF1Data_4
MazePF1Data_16
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........|
   .byte $FF ; |XXXXXXXX|
MazePF1Data_1
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $FF ; |XXXXXXXX|
MazePF2Data_4
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $07 ; |.....XXX|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
MazePF2Data_2
MazePF2Data_22
MazePF2Data_36
MazePF2Data_49
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
MazePF2Data_1
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $07 ; |.....XXX|
   .byte $00 ; |........|
   .byte $00 ; |........|
MazePF2Data_7
MazePF2Data_25
MazePF2Data_39
MazePF2Data_52
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $FF ; |XXXXXXXX|
   .byte $FF ; |XXXXXXXX|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
MazePF1Data_0
MazePF1Data_21
MazePF1Data_35
MazePF1Data_48
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $0F ; |....XXXX|
   .byte $0F ; |....XXXX|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|

   org  $1C00
   rorg $DC00

;skip past page break...free space
   .byte $00 ; |........|
   .byte $00 ; |........|

MazePF0Data_17
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|

   .byte $E0 ; |XXX.....|
   .byte $E0 ; |XXX.....|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
MazePF0Data_11
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $E0 ; |XXX.....|
   .byte $E0 ; |XXX.....|

   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
MazePF0Data_4
MazePF0Data_16
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $E0 ; |XXX.....|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $02 ; |......X.|
   .byte $02 ; |......X.|
   .byte $02 ; |......X.|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
MazePF0Data_1 ;upper nybble used for playfield only
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $E0 ; |XXX.....|
;center door on edge...
MazePF0Data_0 ;upper nybble used for playfield only
MazePF0Data_2
MazePF0Data_3
MazePF0Data_6
MazePF0Data_7
MazePF0Data_8
MazePF0Data_9
MazePF0Data_10
MazePF0Data_12
MazePF0Data_13
MazePF0Data_14
MazePF0Data_15
MazePF0Data_20
MazePF0Data_47
MazePF0Data_62
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....| shared
   .byte $20 ; |..X.....|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
;
; NOTE: Below values not used for maze data...they are used for missile data
;
MissileData: ;LSB must be >$4F
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $02 ; |......X.|
   org  $1CB3
   rorg $DCB3
MazePF1Data_2
MazePF1Data_20
MazePF1Data_22
MazePF1Data_36
MazePF1Data_49
MazePF1Data_61
MazePF1Data_62
MazePF1Data_63
MazePF1Data_64
MazePF2Data_3
MazePF2Data_20
MazePF2Data_23
MazePF2Data_37
MazePF2Data_50
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
MazePF1Data_3
MazePF1Data_23
MazePF1Data_37
MazePF1Data_50
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|

   org  $1D00
   rorg $DD00

;skip past page break...free space
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|

MazePF2Data_15
MazePF2Data_32
MazePF2Data_46
MazePF2Data_59
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $FF ; |XXXXXXXX|
   .byte $FF ; |XXXXXXXX|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
MazePF1Data_5
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
MazePF2Data_5
   .byte $04 ; |.....X..| shared x 2
   .byte $04 ; |.....X..| shared x 2
   .byte $04 ; |.....X..| shared x 2
   .byte $04 ; |.....X..| shared x 2
   .byte $04 ; |.....X..| shared x 2
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $04 ; |.....X..| shared
   .byte $00 ; |........|
   .byte $00 ; |........|
MazePF1Data_7
MazePF1Data_25
MazePF1Data_39
MazePF1Data_52
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $1F ; |...XXXXX|
   .byte $1F ; |...XXXXX|
MazePF2Data_8
MazePF2Data_26
MazePF2Data_40
MazePF2Data_53
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
MazePF2Data_0
MazePF2Data_21
MazePF2Data_35
MazePF2Data_48
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
MazePF2Data_6
MazePF2Data_24
MazePF2Data_38
MazePF2Data_51
   .byte $00 ; |........| shared x 3
   .byte $00 ; |........| shared x 3
   .byte $00 ; |........| shared x 3
   .byte $00 ; |........| shared x 3
   .byte $00 ; |........| shared x 3
   .byte $00 ; |........| shared x 3
   .byte $00 ; |........| shared x 3
   .byte $00 ; |........| shared x 3
   .byte $00 ; |........| shared x 3
   .byte $00 ; |........| shared x 3
   .byte $FF ; |XXXXXXXX| shared x 2
   .byte $FF ; |XXXXXXXX| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
MazePF2Data_9
MazePF2Data_27
MazePF2Data_41
MazePF2Data_54
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared x 2
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $FF ; |XXXXXXXX|
   .byte $FF ; |XXXXXXXX|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
MazePF1Data_11
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $F8 ; |XXXXX...|
   .byte $F8 ; |XXXXX...|
   .byte $00 ; |........|
MazePF1Data_17
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $1F ; |...XXXXX| shared
   .byte $1F ; |...XXXXX| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........|
   .byte $F8 ; |XXXXX...|
   .byte $F8 ; |XXXXX...|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
MazePF2Data_11
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $FF ; |XXXXXXXX|
   .byte $FF ; |XXXXXXXX|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|

BonusIcons
   .byte <Blank
   .byte <Bonus1k
   .byte <Bonus2k
   .byte <Blank

   org  $1E00
   rorg $DE00

NumberFonts
zero
   .byte $30 ; |..XX....|
   .byte $48 ; |.X..X...|
   .byte $84 ; |X....X..|
   .byte $84 ; |X....X..|
   .byte $84 ; |X....X..|
   .byte $48 ; |.X..X...|
   .byte $30 ; |..XX....|
   .byte $00 ; |........|
one
   .byte $38 ; |..XXX...|
   .byte $10 ; |...X....|
   .byte $10 ; |...X....|
   .byte $10 ; |...X....|
   .byte $10 ; |...X....|
   .byte $30 ; |..XX....|
   .byte $10 ; |...X....|
   .byte $00 ; |........|
two
   .byte $FC ; |XXXXXX..|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $78 ; |.XXXX...|
   .byte $04 ; |.....X..|
   .byte $84 ; |X....X..|
   .byte $78 ; |.XXXX...|
   .byte $00 ; |........|
three
   .byte $78 ; |.XXXX...|
   .byte $84 ; |X....X..|
   .byte $04 ; |.....X..|
   .byte $38 ; |..XXX...|
   .byte $04 ; |.....X..|
   .byte $84 ; |X....X..|
   .byte $78 ; |.XXXX...|
   .byte $00 ; |........|
four
   .byte $08 ; |....X...|
   .byte $08 ; |....X...|
   .byte $FC ; |XXXXXX..|
   .byte $48 ; |.X..X...|
   .byte $28 ; |..X.X...|
   .byte $18 ; |...XX...|
   .byte $08 ; |....X...|
   .byte $00 ; |........|
five
   .byte $78 ; |.XXXX...|
   .byte $84 ; |X....X..|
   .byte $04 ; |.....X..|
   .byte $78 ; |.XXXX...|
   .byte $80 ; |X.......|
   .byte $80 ; |X.......|
   .byte $FC ; |XXXXXX..|
   .byte $00 ; |........|
six
   .byte $78 ; |.XXXX...|
   .byte $84 ; |X....X..|
   .byte $84 ; |X....X..|
   .byte $F8 ; |XXXXX...|
   .byte $80 ; |X.......|
   .byte $84 ; |X....X..|
   .byte $78 ; |.XXXX...|
   .byte $00 ; |........|
seven
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $10 ; |...X....|
   .byte $10 ; |...X....|
   .byte $08 ; |....X...|
   .byte $04 ; |.....X..|
   .byte $FC ; |XXXXXX..|
   .byte $00 ; |........|
eight
   .byte $78 ; |.XXXX...|
   .byte $84 ; |X....X..|
   .byte $84 ; |X....X..|
   .byte $78 ; |.XXXX...|
   .byte $84 ; |X....X..|
   .byte $84 ; |X....X..|
   .byte $78 ; |.XXXX...|
   .byte $00 ; |........|
nine
   .byte $78 ; |.XXXX...|
   .byte $84 ; |X....X..|
   .byte $04 ; |.....X..|
   .byte $7C ; |.XXXXX..|
   .byte $84 ; |X....X..|
   .byte $84 ; |X....X..|
   .byte $78 ; |.XXXX...|
   .byte $00 ; |........|

Copyright_0
   .byte $FF ; |XXXXXXXX|
   .byte $00 ; |........|
   .byte $93 ; |X..X..XX|
   .byte $95 ; |X..X.X.X|
   .byte $B5 ; |X.XX.X.X|
   .byte $D5 ; |XX.X.X.X|
   .byte $90 ; |X..X....|
   .byte $00 ; |........|
Copyright_1
   .byte $FF ; |XXXXXXXX|
   .byte $00 ; |........|
   .byte $4B ; |.X..X.XX|
   .byte $56 ; |.X.X.XX.|
   .byte $65 ; |.XX..X.X|
   .byte $53 ; |.X.X..XX|
   .byte $40 ; |.X......|
   .byte $00 ; |........|
Copyright_2
   .byte $E0 ; |XXX.....|
   .byte $10 ; |...X....|
   .byte $30 ; |..XX....|
   .byte $50 ; |.X.X....|
   .byte $50 ; |.X.X....|
   .byte $52 ; |.X.X..X.|
   .byte $06 ; |.....XX.|
   .byte $00 ; |........|
Copyright_3
   .byte $55 ; |.X.X.X.X|
   .byte $55 ; |.X.X.X.X|
   .byte $75 ; |.XXX.X.X|
   .byte $55 ; |.X.X.X.X|
   .byte $55 ; |.X.X.X.X|
   .byte $24 ; |..X..X..|
   .byte $1F ; |...XXXXX|
   .byte $00 ; |........|
Copyright_4
   .byte $55 ; |.X.X.X.X|
   .byte $55 ; |.X.X.X.X|
   .byte $D9 ; |XX.XX..X|
   .byte $55 ; |.X.X.X.X|
   .byte $55 ; |.X.X.X.X|
   .byte $99 ; |X..XX..X|
   .byte $00 ; |........|
   .byte $00 ; |........|

Blank
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|

Bonus1k
   .byte $2A ; |..X.X.X.|
   .byte $2C ; |..X.XX..|
   .byte $2A ; |..X.X.X.|
   .byte $20 ; |..X.....|
   .byte $60 ; |.XX.....|
   .byte $20 ; |..X.....|
   .byte $00 ; |........|

Bonus2k
   .byte $6A ; |.XX.X.X.|
   .byte $4C ; |.X..XX..|
   .byte $4A ; |.X..X.X.|
   .byte $20 ; |..X.....|
   .byte $20 ; |..X.....|
   .byte $60 ; |.XX.....|
   .byte $00 ; |........|

MissileGames
   .byte $03 ; |......XX|
   .byte $03 ; |......XX|
   .byte $0F ; |....XXXX|
   .byte $7B ; |.XXXX.XX|
   .byte $FE ; |XXXXXXX.|
   .byte $03 ; |......XX|
   .byte $00 ; |........|

OttoGames
   .byte $1C ; |...XXX..|
   .byte $22 ; |..X...X.|
   .byte $5D ; |.X.XXX.X|
   .byte $7F ; |.XXXXXXX|
   .byte $2A ; |..X.X.X.|
   .byte $1C ; |...XXX..|
   .byte $00 ; |........|

LivesIndicator2
   .byte $34 ; |..XX.X..|
   .byte $34 ; |..XX.X..|
   .byte $34 ; |..XX.X..|
   .byte $B5 ; |X.XX.X.X|
   .byte $7A ; |.XXXX.X.|
   .byte $00 ; |........|
   .byte $34 ; |..XX.X..|

LivesIndicator
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $5A ; |.X.XX.X.|
   .byte $3C ; |..XXXX..|
   .byte $00 ; |........|
   .byte $18 ; |...XX...|

   org  $1EA9
   rorg $DEA9
PlayerSprites
PlayerStationary
   .byte $00 ; |........|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $00 ; |........|
   .byte $3C ; |..XXXX..|
   .byte $5A ; |.X XX.X.|
   .byte $5A ; |.X XX.X.|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $1C ; |...XXX..|
   .byte $00 ; |........|
PlayerRunning0
   .byte $00 ; |........|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $00 ; |........|
   .byte $38 ; |..XXX...|
   .byte $58 ; |.X.XX...|
   .byte $3C ; |..XXXX..|
   .byte $18 ; |...XX...|
   .byte $08 ; |....X...|
   .byte $64 ; |.XX..X..|
   .byte $44 ; |.X...X..|
   .byte $00 ; |........|
PlayerRunning1
   .byte $00 ; |........|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $00 ; |........|
   .byte $38 ; |..XXX...|
   .byte $18 ; |...XX...|
   .byte $3C ; |..XXXX..|
   .byte $18 ; |...XX...|
   .byte $F4 ; |XXXX.X..|
   .byte $82 ; |X.....X.|
   .byte $03 ; |......XX|
   .byte $00 ; |........|
   .byte $00 ; |........|

PlayerDeath
   .byte $3C ; |..XXXX..|
   .byte $24 ; |..X..X..|
   .byte $24 ; |..X..X..|
   .byte $3C ; |..XXXX..|
   .byte $C3 ; |XX....XX|
   .byte $A5 ; |X.X..X.X|
   .byte $A5 ; |X.X..X.X|
   .byte $E7 ; |XXX..XXX|
   .byte $26 ; |..X..XX.|
   .byte $22 ; |..X...X.|
   .byte $2E ; |..X.XXX.|
   .byte $38 ; |..XXX...|
PlayerFireHoriz
   .byte $00 ; |........|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $00 ; |........|
   .byte $1E ; |...XXXX.|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $1C ; |...XXX..|
   .byte $00 ; |........|
PlayerFireDown
   .byte $00 ; |........|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $00 ; |........|
   .byte $3C ; |..XXXX..|
   .byte $3A ; |..XXX.X.|
   .byte $3A ; |..XXX.X.|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $1C ; |...XXX..|
   .byte $00 ; |........|
PlayerFireUp
   .byte $00 ; |........|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $02 ; |......X.|
   .byte $1C ; |...XXX..|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $1C ; |...XXX..|
   .byte $00 ; |........|
   .byte $00 ; |........|

   org  $1EFF
   rorg $DEFF

.jumpToLivesKernel
   ldx #10
.livesPointerLoop
   dey
   bmi skipahead
   sta digitPointer,x
   bpl skipahead2 ;always branch

skipahead:
   dec $2E ;waste
skipahead2:
   dex
   dex
   bpl .livesPointerLoop
   lda numberOfLives
   cmp #07
   bcs Display_Number_Of_Lives
   jmp Dont_Display_Number_Of_Lives

Display_Number_Of_Lives:
   ldx #3
   jmp Display_Number_Of_Lives2

jp_bottom_table:
   .byte $07
jp_top_table:
   .byte $FF,$07,$07,$07

RobotColorTableBank0 ;duplicate table exists in the next bank (required)
   .byte YELLOW+10,RED_4+6,BLACK+12,LT_GREEN,RED_2+12
   .byte GREEN_BLUE,BROWN+12,PURPLE+8

RobotGraphics
RobotStandingAnimation
StandingAnimation0
   .byte $3C ; |..XXXX..|
   .byte $7E ; |.XXXXXX.|
   .byte $FF ; |XXXXXXXX|
   .byte $BD ; |X.XXXX.X|
   .byte $BD ; |X.XXXX.X|
   .byte $24 ; |..X..X..|
   .byte $24 ; |..X..X..|
   .byte $66 ; |.XX..XX.|
   .byte $00 ; |........|
StandingAnimation1
   .byte $3C ; |..XXXX..|
   .byte $3E ; |..XXXXX.|
   .byte $FF ; |XXXXXXXX|
   .byte $BD ; |X.XXXX.X|
   .byte $BD ; |X.XXXX.X|
   .byte $24 ; |..X..X..|
   .byte $24 ; |..X..X..|
   .byte $66 ; |.XX..XX.|
   .byte $00 ; |........|
StandingAnimation2
   .byte $3C ; |..XXXX..|
   .byte $1E ; |...XXXX.|
   .byte $FF ; |XXXXXXXX|
   .byte $BD ; |X.XXXX.X|
   .byte $BD ; |X.XXXX.X|
   .byte $24 ; |..X..X..|
   .byte $24 ; |..X..X..|
   .byte $66 ; |.XX..XX.|
   .byte $00 ; |........|
StandingAnimation3
   .byte $3C ; |..XXXX..|
   .byte $4E ; |.X..XXX.|
   .byte $FF ; |XXXXXXXX|
   .byte $BD ; |X.XXXX.X|
   .byte $BD ; |X.XXXX.X|
   .byte $24 ; |..X..X..|
   .byte $24 ; |..X..X..|
   .byte $66 ; |.XX..XX.|
   .byte $00 ; |........|
StandingAnimation4
   .byte $3C ; |..XXXX..|
   .byte $66 ; |.XX..XX.|
   .byte $FF ; |XXXXXXXX|
   .byte $BD ; |X.XXXX.X|
   .byte $BD ; |X.XXXX.X|
   .byte $24 ; |..X..X..|
   .byte $24 ; |..X..X..|
   .byte $66 ; |.XX..XX.|
   .byte $00 ; |........|
StandingAnimation5
   .byte $3C ; |..XXXX..|
   .byte $72 ; |.XXX..X.|
   .byte $FF ; |XXXXXXXX|
   .byte $BD ; |X.XXXX.X|
   .byte $BD ; |X.XXXX.X|
   .byte $24 ; |..X..X..|
   .byte $24 ; |..X..X..|
   .byte $66 ; |.XX..XX.|
   .byte $00 ; |........|
StandingAnimation6
   .byte $3C ; |..XXXX..|
   .byte $78 ; |.XXXX...|
   .byte $FF ; |XXXXXXXX|
   .byte $BD ; |X.XXXX.X|
   .byte $BD ; |X.XXXX.X|
   .byte $24 ; |..X..X..|
   .byte $24 ; |..X..X..|
   .byte $66 ; |.XX..XX.|
   .byte $00 ; |........|
StandingAnimation7
   .byte $3C ; |..XXXX..|
   .byte $7C ; |.XXXXX..|
   .byte $FF ; |XXXXXXXX|
   .byte $BD ; |X.XXXX.X|
   .byte $BD ; |X.XXXX.X|
   .byte $24 ; |..X..X..|
   .byte $24 ; |..X..X..|
   .byte $66 ; |.XX..XX.| shares next byte
jp_ball_table:
        .byte $00,$00,$A2,$62

RobotWalkingAnimation
WalkingUpAnimation0
   .byte $3C ; |..XXXX..|
   .byte $7E ; |.XXXXXX.|
   .byte $FF ; |XXXXXXXX|
   .byte $BD ; |X.XXXX.X|
   .byte $BD ; |X.XXXX.X|
   .byte $24 ; |..X..X..|
   .byte $24 ; |..X..X..|
   .byte $64 ; |.XX..X..|
   .byte $06 ; |.....XX.|
WalkingUpAnimation1
   .byte $3C ; |..XXXX..|
   .byte $7E ; |.XXXXXX.|
   .byte $FF ; |XXXXXXXX|
   .byte $BD ; |X.XXXX.X|
   .byte $BD ; |X.XXXX.X|
   .byte $24 ; |..X..X..|
   .byte $24 ; |..X..X..|
   .byte $26 ; |..X..XX.|
   .byte $60 ; |.XX.....|
WalkingLeftAnimation0
   .byte $3C ; |..XXXX..|
   .byte $3E ; |..XXXXX.|
   .byte $FF ; |XXXXXXXX|
   .byte $BD ; |X.XXXX.X|
   .byte $BD ; |X.XXXX.X|
   .byte $24 ; |..X..X..|
   .byte $24 ; |..X..X..|
   .byte $6C ; |.XX.XX..|
   .byte $00 ; |........|
WalkingLeftAnimation1
   .byte $3C ; |..XXXX..|
   .byte $3E ; |..XXXXX.|
   .byte $FF ; |XXXXXXXX|
   .byte $BD ; |X.XXXX.X|
   .byte $BD ; |X.XXXX.X|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $38 ; |..XXX...|
   .byte $00 ; |........|
WalkingRightAnimation0
   .byte $3C ; |..XXXX..|
   .byte $7C ; |.XXXXX..|
   .byte $FF ; |XXXXXXXX|
   .byte $BD ; |X.XXXX.X|
   .byte $BD ; |X.XXXX.X|
   .byte $24 ; |..X..X..|
   .byte $24 ; |..X..X..|
   .byte $36 ; |..XX.XX.|
   .byte $00 ; |........|
WalkingRightAnimation1
   .byte $3C ; |..XXXX..|
   .byte $7C ; |.XXXXX..|
   .byte $FF ; |XXXXXXXX|
   .byte $BD ; |X.XXXX.X|
   .byte $BD ; |X.XXXX.X|
   .byte $18 ; |...XX...|
   .byte $18 ; |...XX...|
   .byte $1C ; |...XXX..|
   org  $1FA9,0
   rorg $DFA9,0
EvilOttoSprites
EvilOttoSprite_0
   .byte $00 ; |........| shared
   .byte $3C ; |..XXXX..|
   .byte $7E ; |.XXXXXX.|
   .byte $DB ; |XX.XX.XX|
   .byte $FF ; |XXXXXXXX|
   .byte $FF ; |XXXXXXXX|
   .byte $BD ; |X.XXXX.X|
   .byte $42 ; |.X....X.|
   .byte $3C ; |..XXXX..|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
EvilOttoSprite_1
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $3C ; |..XXXX..|
   .byte $7E ; |.XXXXXX.|
   .byte $DB ; |XX.XX.XX|
   .byte $FF ; |XXXXXXXX|
   .byte $FF ; |XXXXXXXX|
   .byte $00 ; |........|
   .byte $00 ; |........|
RobotDeathAnimation
DeathAnimation0
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $00 ; |........| shared
   .byte $24 ; |..X..X..|
   .byte $18 ; |...XX...|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $00 ; |........|
DeathAnimation1
   .byte $14 ; |...X.X..|
   .byte $42 ; |.X....X.|
   .byte $81 ; |X......X|
   .byte $24 ; |..X..X..|
   .byte $00 ; |........|
   .byte $00 ; |........|
   .byte $52 ; |.X.X..X.|
   .byte $24 ; |..X..X..|
   .byte $00 ; |........|
DeathAnimation2
   .byte $42 ; |.X....X.|
   .byte $81 ; |X......X|
   .byte $24 ; |..X..X..|
   .byte $00 ; |........|
   .byte $42 ; |.X....X.|
   .byte $3C ; |..XXXX..|
   .byte $81 ; |X......X|
   .byte $42 ; |.X....X.|
   .byte $00 ; |........|

WalkingDownAnimation0
   .byte $3C ; |..XXXX..|
   .byte $66 ; |.XX..XX.|
   .byte $FF ; |XXXXXXXX|
   .byte $BD ; |X.XXXX.X|
   .byte $BD ; |X.XXXX.X|
   .byte $24 ; |..X..X..|
   .byte $24 ; |..X..X..|
   .byte $64 ; |.XX..X..|
   .byte $06 ; |.....XX.|
WalkingDownAnimation1
   .byte $3C ; |..XXXX..|
   .byte $66 ; |.XX..XX.|
   .byte $FF ; |XXXXXXXX|
   .byte $BD ; |X.XXXX.X|
   .byte $BD ; |X.XXXX.X|
   .byte $24 ; |..X..X..|
   .byte $24 ; |..X..X..|
   .byte $26 ; |..X..XX.|
   .byte $60 ; |.XX.....|

AudioFrequencyTable
   .byte $84,$00,$1F,$10,$02,$0A,$11,$18

PcolorTab:
   .byte PLAYER_COLOR
   .byte PLAYER2_COLOR

   org  $1FF8
   rorg $DFF8
   .byte 0 ;unused
Start1
   jmp ColdStart ;hotspot JMP...automatically sets second bank
   .word Start1,Start1





   SEG Bank1
   org  $2000
   rorg $F000

;GoToBank1
JumpIntoGameKernel
   bit $1FF8

   IF COMPILE_VERSION = NTSC

      ldx #$FF

   ELSE

      ldx #20-4
.skip21Scanlines
      sta WSYNC
      dex
      bpl .skip21Scanlines

   ENDIF

   txs                              ; reset stack
   lda #3
   sta VBLANK                       ; disable TIA (D1 = 1)
   lda #OVERSCAN_TIME
   sta TIM64T                       ; set timer for overscan wait
   ldx gameSelection
   lda GameVariationTable,x         ; set the game variation based on game
   sta gameVariation                ; selection
;   ldx #0
;   stx robotCoarsePos               ; bugfix
   lda gameState                    ; get the current game state
   bpl .skipPlayerExitingRoom       ; branch if not exiting room
   jmp SetupForPlayerExitingRoom

.skipPlayerExitingRoom
   ldx #START_GAME_RAM              ; set x to point to start of game RAM
   lda numberOfLives                ; get number of lives remaining
   cmp #$FF
   bne ReadConsoleSwitches          ; if positive skip joystick quick start
   lda INPT4                        ; read joystick button for quick start
   bpl .resetGame                   ; button pressed so reset game
ReadConsoleSwitches
   lda SWCHB                        ; read console switches
;added flippy switch routine
   tax                            ;2
   eor    console                 ;3 Compare with what was before
   and    #BW_MASK                ;2 keep only color switch
   beq    NoToggle                ;2
   lda    console                 ;2
   lsr                            ;2 bit 1 = console type
   bcc    A2600                   ;2
   txa                            ;2
   asl                            ;2
   and    #BW_MASK                ;2 keep only color switch
   bne    NoToggle                ;2
A2600:
   lda    console                 ;3
   eor    #$04                    ;2 flip toggle
   .byte $2C                      ;4 skip 2 bytes
NoToggle:
   lda    console                 ;3
   and    #$F7                    ;2 keep settings
   sta    console                 ;3
   txa                            ;2
   and    #BW_MASK                ;2 keep only color switch
   ora    console                 ;3
   sta    console                 ;3
   lda SWCHB                        ; read console switches
   and #RESET_MASK                  ; mask values to get RESET value
   bne .skipGameReset               ; branch if RESET not pressed
.resetGame
   ldy frameCount                   ; get frame count for random seed MSB
   lda #0
   ldx #START_GAME_RAM
.clearLoop2
   sta VSYNC,x
   inx
   bne .clearLoop2
   jmp ClearRAM2                    ; jump past copyright store

.skipGameReset
   lda gameSelection                ; get current game selection
   bne .checkSelectSwitchDown
   inc gameSelection                ; increment game selection so value = 1
.checkSelectSwitchDown
   lda SWCHB                        ; read console switches
   and #SELECT_MASK                 ; mask the SELECT value
   bne .setSelectDebounce
   sta AUDV0                        ; turn off game sounds player if
   sta AUDV1                        ; selecting a game (a = 0)

;bugfix
   sta robotMissileDirection        ; clear robot missile direction
   sta playerMissileDirection       ;
   sta robotMissileFlightTime       ;
   sta playerMissileFlightTime      ;

   lda selectDebounce               ; get select debounce flag
   bne .reduceSelectDebounce
SetGameSelection
   ldx gameSelection                ; get the current game selection
   cpx #MAX_GAME_SELECTION          ;
   bcc IncrementGameSelection       ;
   ldx #0                           ;
IncrementGameSelection
   inx                              ;
   stx gameSelection                ; save current game selection
   clc                              ;
   sed                              ; set to decimal mode
SetGameSelectionLoop
   adc #1                           ; increase game number by 1 for display
   dex                              ;
   bne SetGameSelectionLoop         ;
   cld                              ; clear decimal mode
   sta playerScore                  ; place in player score to display
   sta playerScore+1                ; ""

   lda #$FF                         ;
   sta playerScore+2                ; set these values to point to the Blank character
   sta playerScore+3                ; ""
   sta playerScore+4                ; ""
   sta playerScore+5                ; ""
   sta numberOfLives                ; set number of lives so joystick quick start is available
   sta numberOfLives+1              ; set number of lives so joystick quick start is available


   sta initRobotDelay
   lda #SELECT_DELAY
.setSelectDebounce
   sta selectDebounce
.reduceSelectDebounce
   dec selectDebounce
;bugfix...set player sprite to default
   lda #$0                          ;
   sta playerGraphicLSB

   lda numberOfLives
   cmp #$FF
   bne .skipAttractModeColorCycling ; branch if not selecting a game
   lda frameCount                   ; get the current frame count
   bne ColorForAttractMode

   inc colorEOR                     ; updated every 255 frames

   jsr SwapPlayers
ColorForAttractMode
   ldx #3
.attractModeLoop
   lda AttractModeColors,x
   eor colorEOR
   and #COLOR_LIGHT_LUM
   sta COLUP0,x
   dex
   bpl .attractModeLoop
   bmi .jmpToDetermineOttoParms     ; always branch

.skipAttractModeColorCycling
   lda initRobotDelay               ; get starting robot delay
   cmp #$FF
   beq DetermineToTurnOffMissiles
   sec                              ; set carry
   ror initRobotDelay               ; shift bits right and move carry into D7
.jmpToDetermineOttoParms
   jmp DetermineEvilOttoParameters

DetermineToTurnOffMissiles
   ldx #0
   ldy #3
   lda robotMissileHorizPos         ; get robot's missile horizontal position
.checkRobotMissileXLimit
   cmp MissileVerticalLimitsTable,y ; see if the missile is out of range
   beq TurnOffRobotMissile          ; turn off missile if out of range
   dey
   bpl .checkRobotMissileXLimit
   lda robotMissileVertPos          ; get the missile's vertical position
   beq TurnOffRobotMissile          ; turn off missile if reached upper limit
   cmp #(H_KERNEL - 8) / 2
   beq TurnOffRobotMissile          ; turn off missile if reached lower limit
   bit CXPPMM
   bvs TurnOffRobotMissile          ; branch if missiles collided
   bit CXM1P
   bvs TurnOffRobotMissile          ; branch if robot missile hit robot
   bmi TurnOffRobotMissile          ; branch if robot missile hit player
   bit CXM1FB
   bpl CheckToTurnOffPlayerMissile  ; branch if robot missile did not hit PF
TurnOffRobotMissile
   lda robotMissileDirection        ; get the robot's missile direction
   cmp #%00001111
   beq .resetRobotMissileLSB        ; branch if no direction (not moving)
   stx robotMissileDirection        ; set robot missile direction to 0
.resetRobotMissileLSB
   stx robotMissilePointer
   stx AUDV1                        ; turn off sound channel 1
   lda #>MissileData
   sta robotMissilePointer+1        ; set MSB for robot missile pointer
CheckToTurnOffPlayerMissile
   ldy #3
   lda playerMissileHorizPos        ; get player's missile horizontal position
.checkPlayerMissileXLimit
   cmp MissileVerticalLimitsTable,y ; see if the missile is out of range
   beq TurnOffPlayerMissile
   dey
   bpl .checkPlayerMissileXLimit
   lda playerMissileVertPos         ; get player's missile vertical position
   beq TurnOffPlayerMissile         ; turn off missile if reached upper limit
   cmp #(H_KERNEL - 8) / 2
   beq TurnOffPlayerMissile         ; turn off missile if reached lower limit
   bit CXPPMM
   bvs TurnOffPlayerMissile         ; branch if missiles collided
   bit CXM0P
   bvs TurnOffPlayerMissile         ; branch if player missile hit Otto
   bmi TurnOffPlayerMissile         ; branch if player missile hit robot
   bit CXM0FB
   bvs TurnOffPlayerMissile         ; branch if player missile hit BALL???
   bpl DeterminePlayerSpriteAnimation; branch if player missile didn't hit PF
TurnOffPlayerMissile
   stx AUDV0
   stx playerMissileFlightTime
   stx playerMissilePointer
   lda #>MissileData
   sta playerMissilePointer+1       ; set MSB for player missile pointer
   bit CXM0P
   bvc DeterminePlayerSpriteAnimation; branch if player missile didn't hit Otto
   lda gameVariation                ; get the game variation
   and #OTTO_REBOUND
   beq DeterminePlayerSpriteAnimation
   lda #2
   sta evilOttoLaunchTimer          ; set Otto to launch in ~4 seconds
   sta CXCLR                        ; clear all collisions
DeterminePlayerSpriteAnimation
   lda playerAnimationIndex         ; get player animation index
   cmp #PLAYER_DEATH_ANIM_OFFSET
   bcc CheckPlayerOttoCollision
   bpl DetermineDeathAnimationSprite

   lda numberOfLives
   sed
   sec
   sbc #01 ;BCD
   cld
   bcs NoRollover
   lda #$FF ;set player to inactive
NoRollover:
   sta numberOfLives

   lda gameState
   ora #%01000000
   sta gameState

   ldy #3
   jmp IncrementGameLevel

DetermineDeathAnimationSprite
   inc playerAnimationIndex         ; increment animation index
   ldx #<(PlayerStationary-PlayerSprites)
   and #2
   beq .setDeathAudioFrequency
   ldx #<(PlayerDeath-PlayerSprites)  ; pointer to death animation sprite
   lda #1
.setDeathAudioFrequency
   sta AUDF0
   stx playerGraphicLSB
   lda #14
   sta AUDV0
   jmp DeterminePlayerMissileActive

CheckPlayerOttoCollision
   lda evilOttoLaunchTimer          ; get Otto launch timer
   cmp #3                           ; don't check Otto's movement if not
   bcc CheckPlayerHarmfulCollisions ; time to launch
   lda frameCount                   ; get current frame count
   ror                              ; rotate D0 into carry
   bcs ReadJoystickValues           ; branch if on an odd frame count
   lda evilOttoHorizPos             ; get Evil Otto's horizontal position
   clc                              ; no need -- carry cleared above
   adc #7
   cmp playerHorizPos               ; compare with player horizontal position
   bcc CheckPlayerHarmfulCollisions
   lda playerHorizPos               ; get player's horizontal position
   clc
   adc #7                           ; could add 6 to save a byte (carry set)
   cmp evilOttoHorizPos             ; compare with Otto's horizontal position
   bcc CheckPlayerHarmfulCollisions
   lda evilOttoVertPos              ; get Otto's vertical position
   clc
   adc #H_PLAYER-1                  ; could add 10 to save a byte (carry set)
   cmp playerVertPos                ; compare with player vertical position
   bcc CheckPlayerHarmfulCollisions
   lda playerVertPos                ; get player's vertical position
   clc
   adc #H_PLAYER+8                  ; could add 19 to save a byte (carry set)
   cmp evilOttoVertPos              ; compare with Otto's vertical position
   bcs .playerHarmfulCollision
CheckPlayerHarmfulCollisions
   lda CXP0FB                       ; die if player hits ball
   asl
   ora CXM1P                        ; die if robot missile hit player
   ora CXPPMM                       ; die if players collided
   ora CXP0FB
   bpl ReadJoystickValues           ; branch if player didn't hit PF

.playerHarmfulCollision
   SPEAK speech_got_the_humanoid  ; VOX 
;skip_voice
   lda #PLAYER_DEATH_ANIM_OFFSET
   sta playerAnimationIndex
   lda #8
   sta AUDC0
   sta audioIndex
   jmp DetermineDeathAnimationSprite

ReadJoystickValues
   lda #0
   sta temp02
   lda #127
   sta randomNumberMax              ; set random number ceiling
   lda PlayerNumber
   and #1
   tay
   lsr
   lda SWCHA                        ; read the joystick values
   bcs PlayerTwo                    ; branch if second stick
   lsr                              ; shift player1's values to lower nybbles
   lsr
   lsr
   lsr
PlayerTwo:
   eor #$0F                         ; flip the bits so high bit shows movement
   and #$0F                         ; mask the upper nybbles (superfluous)
   bne .setPlayerDirection
   lda #PLAYER_STAND_ANIM_OFFSET
   sta playerAnimationIndex
   sta playerGraphicLSB
   sta playerMotion                 ; reset player fractional movement delay
   lda frameCount                   ; get current frame count
   bne CheckForFireButtonPressed    ; branch if not rolled over from 255
   inc attractModeTimer             ; increment attract mode timer
   bne CheckForFireButtonPressed    ; branch if not rolled over from 255
;;   lda gameSelection                ; get current game selection
   jmp SetGameSelection             ; make game go into attract mode

.setPlayerDirection
   sta playerDirection              ; save as player direction
CheckForFireButtonPressed
   ldx playerAnimationIndex
   lda PlayerHorizAnimationTable,x
   sta playerGraphicLSB
   lda.wy INPT4,y                   ; read the joystick fire button
   bmi DeterminePlayerMissileActive ; branch if fire button not pressed
   lda #0
   sta playerMotion                 ; reset player fractional movement delay
   lda playerDirection              ; get the player's direction
   and #MOVE_DOWN | MOVE_UP         ; mask to get up/down value
   tax                              ; move to x for table lookup
   lda PlayerShootingAnimationTable,x
   sta playerGraphicLSB
   lda playerMissileFlightTime
   bne DeterminePlayerMissileActive
   jsr NextRandom
   inc playerMissileFlightTime
   ldx playerDirection              ; get the player's direction
   stx playerMissileDirection       ; save it in the missile direction
   lda playerHorizPos               ; get the player's horizontal position
   clc
   adc InitMissileXOffsetTable,x
   sta playerMissileHorizPos        ; set player's missile horizontal position
   lda playerVertPos                ; get player's vertical position
   lsr                              ; divide by 2 for 2LK
   clc
   adc InitMissileYOffsetTable,x
   sta playerMissileVertPos
   lda #10
   sta AUDC0
   lda #$FF
   sta audioIndex
DeterminePlayerMissileActive
   lda playerMissileFlightTime      ; get player missile flight time
   beq DetermineToMovePlayer        ; branch if time out
   ldx playerMissileDirection       ; get direction missile is moving
   lda playerMissileVertPos
   clc
   adc VerticalPixelOffsets,x
   sta playerMissileVertPos
   lda #<(MissileData-80)
   sec
   sbc playerMissileVertPos
   sta playerMissilePointer
   lda #>MissileData
   sta playerMissilePointer+1
   lda audioIndex
   bpl DeterminePlayerMissilePointer
   lsr
   sta AUDV0
   and #$0F
   beq .skipAudioIndexDecrement
   dec audioIndex
.skipAudioIndexDecrement
   eor #$0F
   sta AUDF0
DeterminePlayerMissilePointer
   lda #ONE_COPY
   sta NUSIZ0
   lda HorizontalPixelOffsets,x
   beq .calculatePlayerMissileOffset
   asl                              ; multiply the value by 2
   clc
   adc playerMissileHorizPos
   sta playerMissileHorizPos
   ldx #MSBL_SIZE4
   stx NUSIZ0
   lda #(H_KERNEL / 2)
.calculatePlayerMissileOffset
   clc
   adc playerMissilePointer
   sta playerMissilePointer
DetermineToMovePlayer
   lda playerAnimationIndex
   cmp #PLAYER_DEATH_ANIM_OFFSET
   bcs DetermineEvilOttoParameters
   lda playerMotion                 ; get the player's fractional delay
;CLC not needed -- carry already clear
   adc #PLAYER_FRACTIONAL_DELAY     ; add in the fractional delay value
   sta playerMotion                 ; set player's fractional delay
   bcc DetermineEvilOttoParameters  ; skip player movement if no roll over
   dec playerAnimationIndex         ; reduce player animation index
   bpl SetPlayerPositions           ; branch if the value didn't roll over
   lda #PLAYER_RUN_ANIM_OFFSET+1
   sta playerAnimationIndex         ; reset animation index for roll over
SetPlayerPositions
   ldx playerDirection              ; get the player's directions
   lda playerVertPos                ; get player's vertical position
   clc
   adc VerticalPixelOffsets,x       ; add vertical pixel values to move
   sta playerVertPos                ; player up or down
   lda playerHorizPos               ; get player's horizontal position
   clc
   adc HorizontalPixelOffsets,x     ; add horizontal pixel value to move
   sta playerHorizPos               ; player left or right
   ldy #PLAYER_ENTERING_WEST        ; assume player is exiting left
   lda playerHorizPos               ; get player's horizontal position
   beq .playerExitingScreen
   iny                              ; check for exiting right (y = 3)
   cmp #XMAX_PLAYER
   bcs .playerExitingScreen
   ldy #PLAYER_ENTERING_NORTH       ; assume player is exiting up
   lda playerVertPos                ; get player's vertical position
   cmp #YMIN + 2
   bcc .playerExitingScreen
   iny                              ; check for exiting down (y = 1)
   cmp #(H_KERNEL - H_PLAYER*2)
   bne DetermineEvilOttoParameters
.playerExitingScreen
   jmp IncrementGameLevel

DetermineEvilOttoParameters
   lda playerDirection
   asl                              ; move right value in D4
   sta REFP0                        ; set player REFLECT state
   lda playerVertPos
   jsr CalculateP0GraphicPointers
   lda #>PlayerSprites
   sta playerGraphicPointer+1
   lda playerMissileHorizPos
   jsr DetermineDiv15Position
   ldx #2
   jsr MoveObjectHorizontally       ; move player's missile
   lda frameCount                   ; get the current frame count
   ror                              ; move D0 to carry
   bcs .calcPlayerXPos              ; branch if on an odd frame
   lda robotVertPos+MAX_ROBOTS-2
   cmp #$7F
   bne .calcPlayerXPos
   lda gameVariation                ; get the game variation
   and #OTTO_INVINCIBLE|OTTO_REBOUND
   beq .calcPlayerXPos              ; branch if no otto
   ldx evilOttoLaunchTimer          ; get Otto launch timer
   cpx #3                           ; branch to move Otto if time to launch
   bcs DetermineEvilOttoMovement
   lda frameCount                   ; get the current frame count
   bne .calcPlayerXPos
   inc evilOttoLaunchTimer          ; increment when frame count rolls to 256
;VOX:
   inx
   cpx #3                           ; check if Otto is going to appear
   bne No_intruder_VOX_Update       ; branch if no otto
   SPEAK speech_intruder_alert      ; VOX
No_intruder_VOX_Update
   lda #1                           ; set to increment Otto's vertical
   sta ottoVerticalDelta            ; position by 1
   ldy playerStartingLocation       ; get the player's starting location
   lda InitVerticalPosition,y       ; read initial vertical position
   sta evilOttoVertPos              ; set it to Otto's vertical position
   sta prevEvilOttoVertPos
   adc #16
   sta tempOttoVertPos
   lda InitHorizontalPosition,y     ; read initial horizontal position
   sta evilOttoHorizPos             ; set it to Otto's horizontal position
.calcPlayerXPos
   jmp CalcPlayerXPos

DetermineEvilOttoMovement
   lda robotVertPos                 ; get the last robot's vertical postion
   cmp #$7F                         ; if not on the screen move Otto faster
   beq .moveEvilOtto
   lda robotMotionDelay             ; get the robot delay value
   asl                              ; multiply by 2 so Otto moves twice as fast
   adc robotMotion
   bcc .setFullEvilOttoSprite
.moveEvilOtto
   lda ottoVerticalDelta
   clc
   adc evilOttoVertPos              ; change Otto's vertical position
   sta evilOttoVertPos
   cmp prevEvilOttoVertPos          ; compare with Otto's previous position
   bcs .determineToBounceOttoUp     ; branch if greater than previous position
   ldx #3                           ; increment Otto's vertical position by 3
.setOttoVerticalDelta
   stx ottoVerticalDelta
   lda prevEvilOttoVertPos          ; get Otto's previous vertical position
   cmp playerVertPos                ; compare with player's vertical position
   bcs .moveOttoUp                  ; branch if Otto is below player
   inc prevEvilOttoVertPos          ; increment Otto's previous position
   inc prevEvilOttoVertPos
   inc prevEvilOttoVertPos          ; do it two more times so fall through
   inc prevEvilOttoVertPos          ; doesn't affect value
.moveOttoUp
   dec prevEvilOttoVertPos
   dec prevEvilOttoVertPos
   lda prevEvilOttoVertPos          ; get Otto's previous vertical position
   clc
   adc #20
   cmp #H_KERNEL - [(H_PLAYER - 1) * 2] + 1
   bcc .setTempOttoVertPos
   lda #H_KERNEL - [(H_PLAYER - 1) * 2]
.setTempOttoVertPos
   sta tempOttoVertPos
DetermineOttoPosition
   ldx ottoVerticalDelta            ; get Otto's vertical delta value
   bmi DetermineOttoHorizPosition   ; branch if we will be moving Otto down
   lda prevEvilOttoVertPos          ; get Otto's previous vertical position
   adc #5
   cmp evilOttoVertPos
   bcs DetermineOttoHorizPosition
   lda tempOttoVertPos
   sta evilOttoVertPos
   lda #<(EvilOttoSprite_1 - EvilOttoSprites) + 2
   jmp .setEvilOttoGraphicLSB       ; could use unconditional branch

DetermineOttoHorizPosition
   lda evilOttoHorizPos             ; get Otto's horizontal position
   cmp playerHorizPos               ; compare with player's horiz position
   beq .setFullEvilOttoSprite
   bcs .moveOttoLeft                ; if greater move Otto lwft
   inc evilOttoHorizPos             ; move Otto right
   inc evilOttoHorizPos             ; again so fall through won't change value
.moveOttoLeft
   dec evilOttoHorizPos             ; move Otto left
.setFullEvilOttoSprite
   lda #<(EvilOttoSprite_0 - EvilOttoSprites) + 1
.setEvilOttoGraphicLSB
   sta playerGraphicLSB
   lda evilOttoVertPos
   jsr CalculateP0GraphicPointers
   lda #>EvilOttoSprites
   sta playerGraphicPointer+1
   lda gameLevel
   lsr                              ; divide value by 2
   and #7
   tax                              ; move to x for robot color lookup
   lda RobotColorTable,x
   sta COLUP0                       ; color Otto
   lda evilOttoHorizPos
   jmp CalcOttoXPos

.determineToBounceOttoUp
   cmp tempOttoVertPos
   bcc DetermineOttoPosition
   ldx #<-4                          ; set Otto vertical delta to move up
   jmp .setOttoVerticalDelta        ; 4 pixels

CalcPlayerXPos
   lda PlayerNumber
   and #1
   tax
   lda PcolorTab2,x
   sta COLUP0                       ; color player
   lda playerHorizPos               ; get the player's horizontal position
CalcOttoXPos
   jsr DetermineDiv15Position
   ldx #0
   jsr MoveObjectHorizontally       ; move player horizontally
VerticalSync SUBROUTINE
   lda PlayerNumber           ; 3
   and #1                     ; 2
   sta PlayerNumber           ; 3
   lda PlayerNumber           ; 3
   ldx numberOfLives          ; get select debounce flag
   inx                        ; 2
   bne Use_Player_Color
   lda gameSelection          ; 3
   eor #1                     ; 2
Use_Player_Color:
   and #1                     ; 2
   tax                        ; 2
   lda PcolorTab2,X           ; 4
   ora PlayerNumber           ; 3
   sta temp03                 ; 3
   SPKOUT temp01              ; service the VOX buffer
.waitTime
   lda INTIM
   bne .waitTime
   lda #%00000011
   sta WSYNC                        ; wait for next scan line
   ;sta VBLANK                       ; diable TIA (D1 = 1)
   sta VSYNC                        ; start vertical sync (D1 = 1)
   sta WSYNC
   inc frameCount
   sta WSYNC
   ldy #VBLANK_TIME
   lda #0
   sty WSYNC
   sta VSYNC
   sty TIM64T                       ; set timer for VBLANK time









;-------------------------
   lda gameState                    ; get the current game state
   bpl DoGameLogic
StoreMazeVectors:
;added to set score vectors to point at maze data instead!
   ldy mazeNumber
   lda MazePF0lsb,y
   sta mazePFpointer
   lda MazePF0msb,y
   sta mazePFpointer+1
   lda MazePF1lsb,y
   sta mazePFpointer+2
   lda MazePF1msb,y
   sta mazePFpointer+3
   lda MazePF2lsb,y
   sta mazePFpointer+4
   lda MazePF2msb,y
   sta mazePFpointer+5
   ldx gameVariation          ; selection
   txs                        ; 2
   ldx #0                     ; 2
   stx robotCoarsePos               ; bugfix
   jmp JumpIntoGameKernel

DoGameLogic:
   jsr NextRandom                   ; re-seed random number
   ldx #0                           ; set to assume robot not to be animated
   clc
   lda robotMotion                  ; get the robot motion value
   adc robotMotionDelay
   sta robotMotion
   bcc .setRobotAnimationDelayValue
   ldx #1                           ; set to show robot is to be animated
.setRobotAnimationDelayValue
   stx delayRobotAnimation
   ldx #0
   stx temp01
.robotMovementLoop
   lda robotVertPos,x               ; get robot's vertical position
   cmp #$7F                         ; see if robot is on the screen
   beq .jmpToNextRobotMovement      ; branch if not on the screen
   ldy robotAnimationIndex,x        ; get the robot's animation index
   cpy #ROBOT_DEATH_ANIM_OFFSET     ; see if the robot is dieing
   bcc .skipRobotDieingCheck        ; branch if robot not dieing
   jmp CheckForRobotDieing

.skipRobotDieingCheck
;;   jsr DetermineTimeToMoveRobot
;;DetermineTimeToMoveRobot
   lda temp01
   bne .setToAllowRobotMovement
   lda playerCollisions+1,x         ; get section player collisions
   beq .setToAllowRobotMovement     ; branch if no collisions
   lda #ROBOT_DEATH_ANIM_OFFSET
   sta robotAnimationIndex,x        ; set the robot animation to dieing
   lda initRobotDelay
   cmp #$FF
   beq .setToSkipRobotMovement
   jsr SortRobotVariables
.setToSkipRobotMovement
   inc temp01
;   sec
;   rts
;.setToAllowRobotMovement
;   clc
;   rts
;   bcs .jmpToNextRobotMovement
   jmp .nextRobotMovement

.setToAllowRobotMovement
   lda delayRobotAnimation          ; get the delay flag for robot animation
   beq .jmpToNextRobotMovement      ; branch if robot not to be animated
   cpy #ROBOT_LEFT_ANIM_OFFSET-1
   bcs .doRobotHorizMovement
.setRobotAnimIndexFromTable
   lda RobotAnimationTable,y
   sta robotAnimationIndex,x
   jmp .nextRobotMovement

.setAnimationIndexToStand
   ldy #ROBOT_STAND_ANIM_OFFSET
   jmp .setRobotAnimIndexFromTable  ; could use unconditional branch

.doRobotHorizMovement
   cpy #ROBOT_STAND_ANIM_OFFSET+8
   bne CheckRobotHorizontalMovement
   lda initRobotDelay
   cmp #$FF
   bne .setRobotAnimIndexFromTable
   jsr DetermineRobotToMove
   cpx compRobotToMove
   bne .setAnimationIndexToStand
   lda random+1
   bpl DetermineRobotMovement
   ldy #ROBOT_DOWN_ANIM_OFFSET      ; assume robot is to move down
   lda playerVertPos                ; get the player's vertical position
   lsr                              ; divide by 2 for 2LK
   cmp robotVertPos,x               ; compare with robot's vertical position
   beq .setAnimationIndexToStand
   bcs .jmpToSetRobotAnimationIndex
   ldy #ROBOT_UP_ANIM_OFFSET+1
.jmpToSetRobotAnimationIndex
   jmp .setRobotAnimationIndex

DetermineRobotMovement
   ldy #ROBOT_RIGHT_ANIM_OFFSET
   lda robotHorizPos,x              ; get robot's horizontal position
   cmp playerHorizPos               ; compare with player's horiz position
   beq .setAnimationIndexToStand
   bcc .setRobotAnimationIndex      ; set robot animation to walk right
   ldy #ROBOT_LEFT_ANIM_OFFSET      ; set animation sprite to walk left
.setRobotAnimationIndex
   sty robotAnimationIndex,x        ; set robot animation index
.jmpToNextRobotMovement
   jmp .nextRobotMovement

CheckRobotHorizontalMovement
   cpy #ROBOT_RIGHT_ANIM_OFFSET
   bcs .checkToMoveRobotRight
   lda robotHorizPos,x              ; get robot's horizontal position
   cmp playerHorizPos               ; compare with player's horiz position
   bcc .setAnimationIndexToStand
   beq .setAnimationIndexToStand
   dec robotHorizPos,x              ; move robot to the left
   jmp .setRobotAnimIndexFromTable

.checkToMoveRobotRight
   cpy #ROBOT_UP_ANIM_OFFSET
   bcs CheckRobotVerticalMovement
   lda robotHorizPos,x              ; get robot's horizontal position
   cmp playerHorizPos               ; compare with player's horiz position
   bcs .setAnimationIndexToStand
   inc robotHorizPos,x              ; move robot to the right
   jmp .setRobotAnimIndexFromTable

CheckRobotVerticalMovement
   cpy #ROBOT_DOWN_ANIM_OFFSET
   bcs .checkToMoveRobotDown
   lda playerVertPos                ; get the player's vertical position
   lsr                              ; divide by 2 for 2LK
   adc #3                           ; add 3 to the value and
   cmp robotVertPos,x               ; compare to robot's vertical position
   beq .setAnimationIndexToStand
   bcs DetermineRobotMovement
   cpy #ROBOT_UP_ANIM_OFFSET
   beq .setAnimIndexFromTable
   cpy #ROBOT_UP_ANIM_OFFSET+2
   beq .setAnimIndexFromTable
   txa
   beq .moveRobotUp
   lda robotVertPos-1,x
   clc
   adc #H_ROBOT+1
   cmp robotVertPos,x
   bcs DetermineRobotMovement
.moveRobotUp
   dec robotVertPos,x
.setAnimIndexFromTable
   jmp .setRobotAnimIndexFromTable

.checkToMoveRobotDown
   lda playerVertPos                ; get the player's vertical position
   lsr                              ; divide by 2 for 2LK
   cmp robotVertPos,x               ; compare with robot's vertical position
   beq DetermineRobotMovement
   bcc DetermineRobotMovement
   cpy #ROBOT_DOWN_ANIM_OFFSET
   beq .skipRobotMovingDown
   cpy #ROBOT_DOWN_ANIM_OFFSET+2
   beq .skipRobotMovingDown
   lda robotVertPos+1               ; get the next robot's vertical position
   cmp #$7F                         ; see if robot is on the screen
   beq .moveRobotDown               ; branch if not on the screen
   lda robotVertPos,x               ; get the robot's vertical position
   clc
   adc #H_ROBOT+2                   ; add the robot height plus pad of 2
   cmp robotVertPos+1,x             ; compare with next robot's position
   bcs DetermineRobotMovement
.moveRobotDown
   inc robotVertPos,x
.skipRobotMovingDown
   jmp .setRobotAnimIndexFromTable

CheckForRobotDieing
   lda playerCollisions+1,x
   beq .incrementRobotAnimation
   inc temp01
.incrementRobotAnimation
   inc robotAnimationIndex,x
   lda robotAnimationIndex,x
   cmp #ROBOT_DEATH_ANIM_OFFSET+4
   bcc .nextRobotMovement
   jsr SortRobotVariables
   lda #SHOOTING_ROBOT_SCORE
   jsr IncrementScore
   inc numberRobotsKilled
   jmp .robotMovementLoop

.nextRobotMovement
   inx
   cpx #MAX_ROBOTS
   beq .doneRobotMovementLoop
   jmp .robotMovementLoop

   IF COMPILE_VERSION = NTSC

.doneRobotMovementLoop
   lda robotVertPos+MAX_ROBOTS-1
   cmp #$7F
   bne .jmpCalcRobotMissileXPos
   lda initRobotDelay

   ELSE

.doneRobotMovementLoop
   lda initRobotDelay

   ENDIF

   cmp #$FF
   beq DetermineToFireRobotMissile
.jmpCalcRobotMissileXPos
   jmp CalcRobotMissileXPos

DetermineToFireRobotMissile
   lda gameLevel                    ; get current game level
   lsr                              ; divide value by 2
   beq .jmpCalcRobotMissileXPos     ; don't fire missiles if first game board
   lda robotMissileDirection        ; get current robot missile direction
   cmp #%00001111
   bne .checkForRobotShootingGame
   inc robotMissileFlightTime
   bpl .jmpCalcRobotMissileXPos
   lda #%00000000
   sta robotMissileDirection        ; clear robot missile direction
.checkForRobotShootingGame
   lda gameVariation                ; get the game variation
;   ror                              ; move ROBOT_SHOOTING to carry
;   bcc .jmpCalcRobotMissileXPos     ; branch if robot's not shooting
   and #NON_SHOOTING
   bne .jmpCalcRobotMissileXPos     ; branch if robot's not shooting

   lda robotMissileDirection        ; get robot missile direction
   beq .determineToLaunchNewMissile
   jmp .determineRobotMissileSize

.determineToLaunchNewMissile
   tay                              ; y = 0
   lda delayRobotAnimation          ; get flag to animate robot this frame
   bne .jmpCalcRobotMissileXPos     ; branch if robot to be animated
   lda #<-1
   sta robotMissileDelay
   lda frameCount                   ; get current frame count
   and #7                           ; make value 0 <= a <= 7
   tax
   lda robotVertPos,x               ; get robot's vertical position
   cmp #$7F                         ; see if robot is on the screen
   beq .jmpCalcRobotMissileXPos     ; branch if robot not on the screen
   lda robotAnimationIndex,x        ; get the robot's animation index
   cmp #ROBOT_DEATH_ANIM_OFFSET     ; see if the robot is dieing
   bcs .jmpCalcRobotMissileXPos     ; branch if robot is dieing
   lda playerHorizPos               ; get the player's horizontal position
;   sec
   sbc #XROBOT_MISSILE_BOX+1        ; carry clear here
   cmp robotHorizPos,x              ; compare with robot's horizontal position
   bcs .checkToLaunchMissileVertically
;CLC not needed -- carry already clear
   adc #XROBOT_MISSILE_BOX*2
   cmp robotHorizPos,x              ; compare with robot's horizontal position
   bcc .checkToLaunchMissileVertically
   ldy #ROBOT_SHOOTING_DOWN
   lda playerVertPos                ; get the player's vertical position
   lsr                              ; divide by 2 for 2LK
   cmp robotVertPos,x               ; compare with robot's vertical position
   bcs .jmpToLaunchRobotMissile
   ldy #ROBOT_SHOOTING_UP
.jmpToLaunchRobotMissile
   sty robotMissileDirection
   lda PlayerNumber
   lsr
   lda #%01000000
   bcc Player_One
   asl
Player_One:
   and SWCHB                        ; check difficulty switches
   beq .combineMissileDirections    ; branch if AMATEUR setting
.checkToLaunchMissileVertically
   lda playerVertPos                ; get player's vertical position
   lsr                              ; divide by 2 for 2LK
   sec
   sbc #YROBOT_MISSILE_BOX
   cmp robotVertPos,x               ; compare with robot's vertical position
   bcs .combineMissileDirections
;CLC not needed -- carry already clear
   adc #YROBOT_MISSILE_BOX*2
   cmp robotVertPos,x
   bcc .combineMissileDirections
   ldy #ROBOT_SHOOTING_LEFT
   lda robotHorizPos,x              ; get robot's horizontal position
   cmp playerHorizPos               ; compare with player's horizontal position
   bcs .combineMissileDirections
   ldy #ROBOT_SHOOTING_RIGHT
.combineMissileDirections
   tya
   ora robotMissileDirection
   sta robotMissileDirection
   beq DetermineMoveRobotMissile
   tay   
LaunchRobotMissile
   lda robotAnimationIndex,x
   cmp #ROBOT_LEFT_ANIM_OFFSET
   bcc .setRobotMissileInitPosition
   lda #ROBOT_STAND_ANIM_OFFSET
   sta robotAnimationIndex,x
.setRobotMissileInitPosition
   lda #<-1
   sta robotMissileSoundIndex
   lda InitRobotMissileYOffset,y
   clc
   adc robotVertPos,x
   sta robotMissileVertPos
   lda InitRobotMissileXOffset,y
   clc
   adc robotHorizPos,x
   sta robotMissileHorizPos
   sty robotMissileDirection
.determineRobotMissileSize
   lda robotMissileDirection        ; get missile direction
   and #%00000011                   ; mask vertical values (keep horiz values)
   beq DetermineMoveRobotMissile    ; branch if not moving horizontally
   lda #MSBL_SIZE4
   sta NUSIZ1                       ; set robot missile size to 4 clocks
DetermineMoveRobotMissile
   lda gameLevel                    ; get current game level
   cmp #16                          ; if greater than 15 then move robot
   bcs .moveRobotMissile            ; missile every frame
   ror                              ; divide by 2 and move D0 to carry
   tax
   lda RobotMissileDelayTable,x
   adc robotMissileDelay            ; carry clear when even game level
   sta robotMissileDelay
   bcc CalcRobotMissileXPos
.moveRobotMissile
   lda robotMissileDirection        ; get missile direction
   beq CalcRobotMissileXPos         ; branch if missile not moving
   cmp #$0F
   beq CalcRobotMissileXPos         ; again...branch if missile not moving
   and #%00001100                   ; mask horiz values (keep vertical values)
   beq CalcRobotMissilePointers     ; branch if not moving vertically
   and #%00000100
   beq .moveRobotMissileUp
   inc robotMissileVertPos          ; move robot missile down
   jmp CalcRobotMissilePointers

.moveRobotMissileUp
   dec robotMissileVertPos
CalcRobotMissilePointers
   lda #<(MissileData-80)
   sec
   sbc robotMissileVertPos
   sta robotMissilePointer
   lda #>MissileData
   sta robotMissilePointer+1
   lda robotMissileSoundIndex
   bpl .skipRobotMissileSound
   lsr                              ; divide the value by 2
   sta AUDV1                        ; to set the volume
   and #$0F
   beq .skipReduceMissileSoundIndex
   dec robotMissileSoundIndex
.skipReduceMissileSoundIndex
   eor #$0F
   sta AUDF1
   lda #$0E
   sta AUDC1
.skipRobotMissileSound
   lda robotMissileDirection        ; get missile direction
   and #%00000011                   ; mask vertical values (keep horiz values)
   beq CalcRobotMissileXPos         ; branch if not moving horizontally
   and #%00000001
   beq .moveRobotMissileLeft
   inc robotMissileHorizPos         ; move robot missile right
   inc robotMissileHorizPos
   jmp Skip_Decs
.moveRobotMissileLeft
   dec robotMissileHorizPos
   dec robotMissileHorizPos
Skip_Decs
   lda #(H_KERNEL / 2)
   clc
   adc robotMissilePointer
   sta robotMissilePointer
CalcRobotMissileXPos SUBROUTINE
   lda robotMissileHorizPos
   jsr DetermineDiv15Position
   ldx #3
   jsr MoveObjectHorizontally       ; move robot's missile
   lda robotMissileSoundIndex
   bmi SetRobotVariables
   sta AUDV1
   beq .skipReduceMissileSoundIndex
   dec robotMissileSoundIndex
.skipReduceMissileSoundIndex
   eor #$0F
   sta AUDF1
   lda #8
   sta AUDC1
SetRobotVariables
   ldx #MAX_ROBOTS-1
.setRobotGraphicPointers
   ldy robotAnimationIndex,x        ; get robot animation index
   lda RobotAnimationTableOffsets,y ; get the LSB value from table
   sta robotPointers,x              ; set robot graphic pointer
   dex
   bpl .setRobotGraphicPointers
   ldx #MAX_ROBOTS-1
.setRobotPositionValues
   lda robotVertPos,x
   cmp #$7F
   beq .nextRobotB
   lda robotHorizPos,x              ; get robot's horizontal position
   jsr DetermineDiv15Position
   sta robotFineHoriz,x             ; set robot's fine horiz value
   dey                              ; reduce coarse position
   tya                              ; move coarse position to accumulator
   cmp #5                           ; if it's less than 5 set coarse value
   bcc .setRobotsCoarseHorizPos
   sbc #4                           ; subtract value by 4
   eor #$FF                         ; make negative to show robot on right
   tay                              ; move coarse value back to y
   iny                              ; increment coarse value
.setRobotsCoarseHorizPos
   sty robotCoarseHoriz,x
.nextRobotB
   dex
   bpl .setRobotPositionValues
   inx
;   ldy #0
   stx kernelSection                ; re-initialize kernel section
   stx temp01
   stx player0Graphic               ; clear player0 graphic buffer
   stx GRP0                         ; clear player0's graphic register
   stx ENAM1                        ; disable robot missile
   stx ENAM0                        ; disable player missile
   stx VDELP1                       ; don't VDEL the robots
   jmp StoreMazeVectors








;21
SwapPlayers:
   ldx #10
SwapLoop:
   lda    playerinfo,X
   ldy    playerinfo+1,X
   sta    playerinfo+1,X
   sty    playerinfo,X
   dex
   dex
   bpl SwapLoop
   lda PlayerNumber
   eor #1
   sta PlayerNumber
   rts







;=======================================
;            boot routine
;=======================================
ColdStart
   lda INTIM                      ; this is used for random number seed
   asl                            ;2 keep low bit clear for console type
   sei                            ;2 Set Interupts Off
   cld                            ;2
   ldx    $D0                     ;3
   cpx    #$2C                    ;2
   bne    SaveConsole             ;2
   ldx    $D1                     ;3
   cpx    #$A9                    ;2
   bne    SaveConsole             ;2
   ora    #$01                    ;2 console = 7800
SaveConsole:
   tay                            ;2
   lda    #$00                    ;2 Clear TIA Registers
   tax                            ;2
;ram init loop...
ResetAll:
   dex                            ;2
   txs                            ;2
   pha                            ;3 Everything Off
   bne    ResetAll                ;2
   tya                            ;2
   and    #$01                    ;2
   sta    console                 ;3 save console type to high bit
   tya                            ;2
   lsr                            ;2 remove console type from RND seed
;;   sta random+1                   ; set the random number seed
   sta mazeNumber                 ; set the random number seed

   dec frameCount

 ;VOX startup sound...
 SPEAK speech_startup

;NOTE: insert a boot screen here if you wish :)
   ldx    #96                     ;2
Ram_Setup:
   lda    MarqueeData-1,x         ;4
   sta    Marquee-1,x             ;4
   dex                            ;2
   bne    Ram_Setup               ;2


   ;eat overscan time...
Splash_Display
   lda INTIM
   bne Splash_Display

   ;perform 3 lines of vsync...
   lda #%00000011
   sta WSYNC                        ; wait for next scan line
   sta VBLANK                       ; diable TIA (D1 = 1)
   sta VSYNC                        ; start vertical sync (D1 = 1)
   sta WSYNC
   dec frameCount
   lda #0
   sta WSYNC

   IF COMPILE_VERSION = NTSC
      ldy #VBLANK_TIME
   ELSE
      ldy #VBLANK_TIME+35
   ENDIF

   sty WSYNC
   sta VSYNC
   sty TIM64T                       ; set timer for VBLANK time

;time here
   lda    frameCount              ;3
   bmi    skiproll                ;2
;;   bne    Do_roll                 ;2
;;   jmp    Splash_Exit              ;3

Do_roll:
   cmp    #78                     ;2
   bcs    skiproll                ;2
   and    #03                     ;2
   bne    skiproll                ;2

   ldx    #15                     ;2
RollLoop:
   ;clc                            ;2
   lsr    Marquee+32,x            ;4
   rol    Marquee+16,x            ;4
   ror    Marquee,x               ;4
   ;clc                            ;2
   asl    Marquee+48,x            ;4
   ror    Marquee+64,x            ;4
   rol    Marquee+80,x            ;4
   dex                            ;2
   bpl    RollLoop                ;2
skiproll:

   ;finish vblank...
SplashDisplayWait:
   lda    INTIM                   ;4
   bne    SplashDisplayWait       ;2
   sta    WSYNC
   sta	  VBLANK

;transfer title bitmap to playfield
   ldx    #15                     ;2
   sta    WSYNC                   ;3
   sta    WSYNC                   ;3
Display_Blocks:
   ldy    #$04                    ;2
Display_Lines:
   lda    #$00                    ;2
   sta    PF0                     ;3
   sta    PF1                     ;3
   sta    PF2                     ;3
   lda    MarqueeShade-1,y        ;4
   sta    WSYNC                   ;3
   ora    MarqueeColor,x          ;4
   sta    COLUPF                  ;3
   lda    Marquee,x               ;4
   sta    PF0                     ;3
   lda    Marquee+16,x            ;4
   sta    PF1                     ;3
   lda    Marquee+32,x            ;4
   sta    PF2                     ;3
   lda    Marquee+48,x            ;4
   sta    PF0                     ;3
   lda    Marquee+64,x            ;4
   sta    PF1                     ;3
   lda    Marquee+80,x            ;4
   sta    PF2                     ;3
   sta    WSYNC                   ;3
   dey                            ;2
   bne    Display_Lines           ;2 @56/7
   sty    PF0                     ;3
   sty    PF1                     ;3
   sty    PF2                     ;3
Next_Block:
   dex                            ;2
   bpl    Display_Blocks          ;2


   ldx    #$04                    ;2
   sta    WSYNC                   ;3
   sta    WSYNC                   ;3

Display_Blocks2:
   ldy    #$02                    ;2
Display_Lines2:
   sta    WSYNC                   ;3
   lda    ScreenShade,x           ;4
   sta    COLUPF                  ;3
   lda    Screen_PF0,x            ;4
   sta    PF0                     ;3
   lda    Screen_PF1,x            ;4
   sta    PF1                     ;3
   lda    Screen_PF2,x            ;4
   sta    PF2                     ;3
   lda    Screen_PF3,x            ;4
   sta    PF0                     ;3
   lda    Screen_PF4,x            ;4
   sta    PF1                     ;3
   lda    Screen_PF5,x            ;4
   sta    PF2                     ;3
   dey                            ;2
   bne    Display_Lines2          ;2 @56/7
   dex                            ;2
   bpl    Display_Blocks2         ;2

   sta    WSYNC                   ;3
   sty    PF0                     ;3
   sty    PF1                     ;3
   sty    PF2                     ;3

;;   ldx    #60-11                  ;2
   ldx    #45                     ;2

   lda    frameCount              ;3
   beq    Blank_Lines            ;2
   ldx    #44
   sta    WSYNC
Blank_Lines
   sta    WSYNC                   ;3
   dex                            ;2
   bpl    Blank_Lines             ;2

   ;start overscan...
   lda #3

 sta    WSYNC                   ;3
   sta    VBLANK                  ;3
   sta    WSYNC                   ;3
   ldy    #OVERSCAN_TIME          ;2 247
   sty    TIM64T                  ;4

Splash_Continue:
   ldx    frameCount              ;3
   beq    Splash_Exit             ;2
   jmp    Splash_Display          ;3 go back for another frame



Splash_Exit:
;   lda #0
;   ldx #START_GAME_RAM
;.clearLoop3
;   sta VSYNC,x
;   inx
;   bne .clearLoop3

   ldx #0


   lda mazeNumber                 ;
   sta random+1                   ;
   stx mazeNumber                 ;

   lda #$19
   sta playerScore
   lda #$82
   sta playerScore+2
   lda #$DE
   sta playerScore+4
   lda #$FA
   sta playerScore+1
   lda #$BC
   sta playerScore+3
   lda #$08
   sta playerScore+5
   ldy random+1                     ; restore seed
ClearRAM2
   stx COLUBK                       ; set background color to BLACK (x = 0)
   lda #BLUE
   sta COLUPF                       ; color the playerfield (i.e. maze)
   lda #%00010001                   ; set BALL to 2 clocks (not used) and
   sta CTRLPF                       ; REFLECT the playfield
   lda #$7F
   sta robotVertPos+MAX_ROBOTS
   sty random+1                     ; set the random number seed
   tya                              ; set up random MSB
   eor #%10110101
   sta random
   lda #%00001111
   sta robotMissileDirection        ; set missile to no direction (not moving)
   ldx #INIT_NUM_LIVES-1
   lda gameState
   bne .setNumberOfLives
   ldx #$FF
.setNumberOfLives
   stx numberOfLives
   lda gameSelection                ; get current game selection
   lsr                              ; check between player 1 or player 2 games
   bcc TwoPlayerGame
   ldx #$FF
TwoPlayerGame:
   stx numberOfLives+1 ;2nd player

   ldy #PLAYER_ENTERING_EAST
   sty playerStartingLocation+1

   ldy #MOVE_DOWN
   sty playerDirection
   iny                              ; y = 3
   inc attractModeTimer
IncrementGameLevel
   inc gameLevel
   sty tempPlayerExitingPos         ; save the player's exiting position
   lda robotVertPos
   cmp #$7F                         ; if all robots not killed
   bne .skipLevelBonus              ; then skip level bonus
   lda numberRobotsKilled           ; get number of robots killed
   asl                              ; multiply the value by 16 to add to
   asl                              ; player's score
   asl
   asl
   jsr IncrementScore
;VOX: set "The humanoid must not escape" pointer (LDA #<data)
   lda #<speech_the_humanoid        
   .byte $2C                        ; VOX: skip past alternate pointer load
.skipLevelBonus
   lda #<speech_chicken
   ldx gameLevel
   cpx #1
   beq skip_leaving_vox ; just started

   ldx playerAnimationIndex
   cpx #PLAYER_DEATH_ANIM_OFFSET
   beq skip_leaving_vox ; just started

   cpy #3 ; the player didn't leave, he was killed
   beq skip_leaving_vox ; just started

   sta speech_addr                  ; set the speech pointer
skip_leaving_vox
   lda #$7F
   sta robotVertPos                 ; set the last robot and
   sta playerVertPos                ; player to out of range (don't show them)
   lda gameLevel                    ; get the current game level
   lsr                              ; divide the value by 2
   and #$07                         ; make the value 0 <= a <= 7
   tax
   lda RobotMotionDelayTable,x
   sta robotMotionDelay
   lda #%00001111
   sta robotMissileDirection        ; set to no missile direction
   lda #0
   sta robotMissileFlightTime
   sta frameCount                   ; reset frame count
   sta robotMissilePointer          ; turn off robot missile
   sta upperPlayfieldLimit
   sta audioIndex
   sta AUDV1                        ; turn off sound channel 1
   sta playerAnimationIndex         ; set player animation state to standing
   sta playerMissileFlightTime
   sta playerMissilePointer         ; turn off player missile
   sta evilOttoLaunchTimer          ; reset Otto launch timer
   lda #(H_KERNEL / 2)
   sta lowerPlayfieldLimit
   lda gameState                    ; get the current game state
   and #%11000011
   cmp #%00000011
   bne .setGameStateToExiting
   lda #5
   sta audioIndex
.setGameStateToExiting
   lda gameState
   and #%01111100
   ora #%10000000
   sta gameState
   jmp DetermineEvilOttoParameters

SetupForPlayerExitingRoom
   ldy tempPlayerExitingPos
   cpy #PLAYER_ENTERING_SOUTH
   beq .skipIncrementUpperPFLimit
   inc upperPlayfieldLimit
.skipIncrementUpperPFLimit
   cpy #PLAYER_ENTERING_NORTH
   beq .skipDecrementLowerPFLimit
   dec lowerPlayfieldLimit
.skipDecrementLowerPFLimit
   lda upperPlayfieldLimit
   cmp lowerPlayfieldLimit
   bcs SetupForNewScreen
   jmp DetermineEvilOttoParameters

SetupForNewScreen
   lda gameState
   and #%01000000
   beq SkipSwap
   ldx numberOfLives+1
   inx
   beq SkipSwap
   jsr SwapPlayers
SkipSwap:

   lda gameState
   and #%00111100
   ora #%00000010
   sta gameState

   ldy tempPlayerExitingPos
   ldx #%00000010
   lda console            ; check B&W status
   and #%00000100
   bne .setMazePF0Value   ; skip playfield sides if doors are used
   cpy #PLAYER_ENTERING_WEST
   bcc .setMazePF0Value
   ldx #%00100000
.setMazePF0Value
   lda mazePF0Value
   and #%00001101
   stx mazePF0Value
   ora mazePF0Value
   sta mazePF0Value
   lda StartingLocationValues,y
   sta playerStartingLocation
   tay
   lda InitVerticalPosition,y
   sta playerVertPos
   lda InitHorizontalPosition,y
   sta playerHorizPos
   jsr DetermineDiv15Position
   ldx #0
   jsr MoveObjectHorizontally       ; move player horizontally

;picking a maze...
;NOTE: to use greater numbers of mazes (other than only 4), the AND value below should reflect
;      the highest exponent of 2 that still falls equal to or less than your total number of
;      mazes (to speed up randomization)...and a comparison done to see if the random value
;      chosen is greater than the total number of mazes (if so, drop the upper bit used to push
;      it below).  Then all you need to do is add maze labels to the "MazePF" tables in this
;      bank...and add data to the first bank.  You can even share bytes now.  Pretty much the
;      only restriction is that maze data cannot cross pages...and each group of 42 bytes must
;      be located at least 2 bytes from a page break.  You can even share entire PF bitmaps
;      between screens (making 256 mazes completely possible within the confines of 8k).
;;original routine...
;;   lda random+1                     ; get high random seed
;;   and #%00000011                   ; make sure 0 <= a <= 3 (4 mazes)
;;   cmp mazeNumber
;;   bne .setMazeNumber
;;   eor #%00000010
;;.setMazeNumber
;;   sta mazeNumber ;store for later
  IF TEST_MAZES
   inc mazeNumber      ; bump maze number
  ELSE
;   lda random+1        ; get high random seed
;   eor numberRobotsKilled  ;fudge value
;   and #MAX_SCREENS    ; keep maximum of 32 values
;   cmp #TOTAL_SCREENS-1 ; within x screens (0-x)?
;   bcc checkmazenumber ; branch if OK
;   lsr                 ; otherwise, cut the highest bit used
   lda numberRobotsKilled  ;fudge value
   asl                 ;
   asl                 ;
   asl                 ;
   eor random+1        ; get high random seed
   and #MAX_SCREENS    ; keep maximum of 32 values
checkmazenumber:
   cmp mazeNumber      ; check against current screen
   bne .setMazeNumber  ; branch if different (ok to use as new screen)
   eor #%00000010      ;  ...otherwise, flip bit 1 to force it to differ
.setMazeNumber
   sta mazeNumber      ;store for later
  ENDIF

ResetRobotsForNewBoard
   ldx #MAX_ROBOTS-1
   lda #0
   sta numberRobotsKilled           ; re-initialize number robots killed
   sta initRobotDelay
   sta temp02
   lda #135
   sta randomNumberMax              ; set random number ceiling
   lda #75                          ; initial vertical position of robot
.nextRobot
   sta lastRobotVertPos
   sta robotVertPos,x               ; set robot's vertical position
   jsr NextRandom                   ; get a random number
   sta robotHorizPos,x              ; set robot random horizontal position
   jsr NextRandom                   ; re-seed random number
   and #7                           ; and with 7 to get standing animation
   sta robotAnimationIndex,x        ; set standing animation of robot
   lda lastRobotVertPos
   sec
   sbc #H_ROBOT+1
   dex
   bpl .nextRobot
   jmp DetermineEvilOttoParameters


 ; ** VOX speech data
 align 256

speech_startup
speech_silence	;just something to point the pointers to at the start
 BYTE 31	; reset
 BYTE $ff

speech_chicken ;chicken fight like a robot...
 BYTE 31 	; reset 
 BYTE 21,116	; speed=116
 BYTE 22,55	; pitch=55
 BYTE 23,4	; bend=4
 BYTE 182,129,194,131,141 	; chicken (\CH \IH \KE \EH \NE)
 BYTE 2 	; pause=2 
 BYTE 2		; pause=2
 BYTE 8, 186, 7, 155, 4, 191	; fight (slow \FF fast \OHIY pause=4 \TT)
 BYTE 6		; pause=6
 BYTE 145, 7, 136, 7, 155,196	; like (\LE fast \AW fast \OHIY \EK)
 BYTE 6		; pause=6
 BYTE 154,128			; a (\EYIY \IY)
 BYTE 6		; pause=6
 BYTE 148, 7, 137, 7, 164, 171, 136, 191 
 	; robot (\RR fast \OW fast \OWWW \BO \AW \TT)
 BYTE $ff	; End Of Data

speech_the_humanoid ;The humanoid must not escape...
 BYTE 31	; reset
 BYTE 21,116	; speed=116
 BYTE 22,55	; pitch=55
 BYTE 23,4	; bend=4
 BYTE 8, 169, 8, 134 		; the (slow \DH slow \UX)
 BYTE 6		; pause=6
 BYTE 184, 7, 160, 140, 134, 7, 142, 7, 137, 7, 156, 176 
				; humanoid (\HO fast \IYUW \MM \UX fast 
				;           \NO fast \OW fast \OWIY \ED)
 BYTE 6		; pause=6
 BYTE 140, 134, 187, 191	; must (\MM \UX \SE \TT)
 BYTE 6		; pause=6
 BYTE 141, 135, 191		; not (\NE \OH \TT)
 BYTE 6		; pause=6
 BYTE 131, 187, 194, 7, 154, 4, 198
 				; escape (\EH \SE \KE fast \EYIY pause=4 \PE)
 BYTE $ff	; End Of Data

speech_got_the_humanoid ; got the humanoid... got the intruder
 BYTE 31	; reset
 BYTE 21,116	; speed=116
 BYTE 22,80	; pitch=80
 BYTE 23,4	; bend=4
 BYTE 8, 179, 134, 134, 191 	; got (slow \GO \OH \OH \TT) 
 BYTE 6		; pause=6
 BYTE 8, 169, 8, 134 		; the (slow \DH slow \UX)
 BYTE 6		; pause=6
 BYTE 184, 7, 160, 140, 134, 7, 142, 7, 137, 7, 156, 176 
				; humanoid (\HO fast \IYUW \MM \UX fast 
				;           \NO fast \OW fast \OWIY \ED)
 BYTE 22,100	; pitch=100
 BYTE 6		; pause=6
 BYTE 8, 179, 134, 134, 191 	; got (slow \GO \OH \OH \TT) 
 BYTE 6		; pause=6
 BYTE 8, 169, 8, 134 		; the (slow \DH slow \UX)
 BYTE 129, 141, 191, 148, 139, 7, 174, 7, 133, 7, 151
	; intruder ( \IH \NE \TT \RR \UW \FAST \DE \FAST \AX \FAST \AXRR) 
 BYTE $ff	; End Of Data

speech_intruder_alert ; intruder alert, intruder alert
 BYTE 31	; reset
 BYTE 21,116	; speed=116
 BYTE 22,100	; pitch=100
 BYTE 23,4	; bend=4
 BYTE 129, 141, 191, 148, 139, 7, 174, 7, 133, 7, 151
	; intruder ( \IH \NE \TT \RR \UW \FAST \DE \FAST \AX \FAST \AXRR)
 BYTE 6		; pause=6
 BYTE 134, 145, 151, 191
	; alert (\UX \LE \AXRR \TT) 
 BYTE 6		; pause=6
 BYTE 129, 141, 191, 148, 139, 7, 174, 7, 133, 7, 151
	; intruder ( \IH \NE \TT \RR \UW \FAST \DE \FAST \AX \FAST \AXRR)
 BYTE 6		; pause=6
 BYTE 134, 145, 151, 191
	; alert (\UX \LE \AXRR \TT) 
 BYTE $ff	; End Of Data


;   org  $2919
;   rorg $F919
;      nop

;1k of free space

   org  $2C17,0
   rorg $FC17,0

;various subroutines...
;38
SortRobotVariables
   txa                              ; move robot index to the accumulator
   tay                              ; save it in y for later
.sortLoop
   lda playerCollisions+2,x         ; get the player's collision value
   sta playerCollisions+1,x         ; bubble it up
   lda robotAnimationIndex+1,x      ; get the robot's collision value
   sta robotAnimationIndex,x        ; and bubble it up
   lda robotHorizPos+1,x            ; get the robot's horizontal position
   sta robotHorizPos,x              ; and bubble it up
   lda robotVertPos+1,x             ; get the robot's vertical position
   sta robotVertPos,x               ; and bubble it up
   inx                              ; increment robot index for next robot
   cmp #$7F                         ; see if the last robot is to be shown
   bne .sortLoop
   inc robotMotionDelay
   inc robotMotionDelay
   lda #$08
   sta AUDC1
   lda #$0F
   sta robotMissileSoundIndex
   tya                              ; move saved robot index to accumulator
   tax                              ; so we can restore it to x
   rts


;32
DetermineRobotToMove
   ldy #3                           ; assume robot 3 will be selected to move
   lda #0
.determineBasedOnHorizPos
   clc
   adc #34
   cmp playerHorizPos
   bcs .determineBasedOnVertPos
   dey                              ; reduce initial robot number to move
   bpl .determineBasedOnHorizPos
.determineBasedOnVertPos
   lda playerVertPos
   cmp #(H_KERNEL / 2) - H_ROBOT + 1
   bcs .getRandomRobotNumber        ; branch if player in bottom half of PF
   iny
   iny
   iny
   iny
.getRandomRobotNumber
   tya                              ; move initial robot number to accumulator
   eor random+1                     ; flip bits based on random seed
   and #7                           ; make sure 0 <= a <= 7
   sta compRobotToMove              ; set the computed robot number to move
   rts



;21
CalculateP0GraphicPointers SUBROUTINE
   sta VDELP0                       ; VDEL the player if on an odd line (2LK)
   lsr                              ; divide by 2 for a 2LK
   sta player0Scanline              ; set scan line number for player0
   clc
   adc #H_PLAYER+1                  ; add with player height
   sta playerUpperBoundary          ; save for sprite drawing ceiling
   lda #H_KERNEL - 7
   sec
   sbc player0Scanline
   clc
   adc playerGraphicLSB
   sta playerGraphicPointer
   rts



;14
MoveObjectHorizontally
   sta WSYNC                        ; wait for next scan line
   SLEEP_4                          ; waste 4 cycles
   sta HMP0,x                       ; set fine motion value
   lda HMP0                         ; waste 3 cycles so subtraction start @ 11
.coarseMoveLoop
   dey
   bpl .coarseMoveLoop
   sta RESP0,x                      ; set object's coarse position
   rts


;LSB/MSB tables of all the mazes.
MazePF0lsb
   .byte <MazePF0Data_0-2
   .byte <MazePF0Data_1-2
   .byte <MazePF0Data_2-2
   .byte <MazePF0Data_3-2
   .byte <MazePF0Data_4-2
   .byte <MazePF0Data_5-2
   .byte <MazePF0Data_6-2
   .byte <MazePF0Data_7-2
   .byte <MazePF0Data_8-2
   .byte <MazePF0Data_9-2
   .byte <MazePF0Data_10-2
   .byte <MazePF0Data_11-2
   .byte <MazePF0Data_12-2
   .byte <MazePF0Data_13-2
   .byte <MazePF0Data_14-2
   .byte <MazePF0Data_15-2
   .byte <MazePF0Data_16-2
   .byte <MazePF0Data_17-2
   .byte <MazePF0Data_18-2
   .byte <MazePF0Data_19-2
   .byte <MazePF0Data_20-2
   .byte <MazePF0Data_21-2
   .byte <MazePF0Data_22-2
   .byte <MazePF0Data_23-2
   .byte <MazePF0Data_24-2
   .byte <MazePF0Data_25-2
   .byte <MazePF0Data_26-2
   .byte <MazePF0Data_27-2
   .byte <MazePF0Data_28-2
   .byte <MazePF0Data_29-2
   .byte <MazePF0Data_30-2
   .byte <MazePF0Data_31-2
   .byte <MazePF0Data_32-2
   .byte <MazePF0Data_33-2
   .byte <MazePF0Data_34-2
   .byte <MazePF0Data_35-2
   .byte <MazePF0Data_36-2
   .byte <MazePF0Data_37-2
   .byte <MazePF0Data_38-2
   .byte <MazePF0Data_39-2
   .byte <MazePF0Data_40-2
   .byte <MazePF0Data_41-2
   .byte <MazePF0Data_42-2
   .byte <MazePF0Data_43-2
   .byte <MazePF0Data_44-2
   .byte <MazePF0Data_45-2
   .byte <MazePF0Data_46-2
   .byte <MazePF0Data_47-2
   .byte <MazePF0Data_48-2
   .byte <MazePF0Data_49-2
   .byte <MazePF0Data_50-2
   .byte <MazePF0Data_51-2
   .byte <MazePF0Data_52-2
   .byte <MazePF0Data_53-2
   .byte <MazePF0Data_54-2
   .byte <MazePF0Data_55-2
   .byte <MazePF0Data_56-2
   .byte <MazePF0Data_57-2
   .byte <MazePF0Data_58-2
   .byte <MazePF0Data_59-2
   .byte <MazePF0Data_60-2
   .byte <MazePF0Data_61-2
   .byte <MazePF0Data_62-2
   .byte <MazePF0Data_63-2

MazePF0msb
   .byte >MazePF0Data_0
   .byte >MazePF0Data_1
   .byte >MazePF0Data_2
   .byte >MazePF0Data_3
   .byte >MazePF0Data_4
   .byte >MazePF0Data_5
   .byte >MazePF0Data_6
   .byte >MazePF0Data_7
   .byte >MazePF0Data_8
   .byte >MazePF0Data_9
   .byte >MazePF0Data_10
   .byte >MazePF0Data_11
   .byte >MazePF0Data_12
   .byte >MazePF0Data_13
   .byte >MazePF0Data_14
   .byte >MazePF0Data_15
   .byte >MazePF0Data_16
   .byte >MazePF0Data_17
   .byte >MazePF0Data_18
   .byte >MazePF0Data_19
   .byte >MazePF0Data_20
   .byte >MazePF0Data_21
   .byte >MazePF0Data_22
   .byte >MazePF0Data_23
   .byte >MazePF0Data_24
   .byte >MazePF0Data_25
   .byte >MazePF0Data_26
   .byte >MazePF0Data_27
   .byte >MazePF0Data_28
   .byte >MazePF0Data_29
   .byte >MazePF0Data_30
   .byte >MazePF0Data_31
   .byte >MazePF0Data_32
   .byte >MazePF0Data_33
   .byte >MazePF0Data_34
   .byte >MazePF0Data_35
   .byte >MazePF0Data_36
   .byte >MazePF0Data_37
   .byte >MazePF0Data_38
   .byte >MazePF0Data_39
   .byte >MazePF0Data_40
   .byte >MazePF0Data_41
   .byte >MazePF0Data_42
   .byte >MazePF0Data_43
   .byte >MazePF0Data_44
   .byte >MazePF0Data_45
   .byte >MazePF0Data_46
   .byte >MazePF0Data_47
   .byte >MazePF0Data_48
   .byte >MazePF0Data_49
   .byte >MazePF0Data_50
   .byte >MazePF0Data_51
   .byte >MazePF0Data_52
   .byte >MazePF0Data_53
   .byte >MazePF0Data_54
   .byte >MazePF0Data_55
   .byte >MazePF0Data_56
   .byte >MazePF0Data_57
   .byte >MazePF0Data_58
   .byte >MazePF0Data_59
   .byte >MazePF0Data_60
   .byte >MazePF0Data_61
   .byte >MazePF0Data_62
   .byte >MazePF0Data_63

   org  $2D00
   rorg $FD00

MazePF1lsb
   .byte <MazePF1Data_0-2
   .byte <MazePF1Data_1-2
   .byte <MazePF1Data_2-2
   .byte <MazePF1Data_3-2
   .byte <MazePF1Data_4-2
   .byte <MazePF1Data_5-2
   .byte <MazePF1Data_6-2
   .byte <MazePF1Data_7-2
   .byte <MazePF1Data_8-2
   .byte <MazePF1Data_9-2
   .byte <MazePF1Data_10-2
   .byte <MazePF1Data_11-2
   .byte <MazePF1Data_12-2
   .byte <MazePF1Data_13-2
   .byte <MazePF1Data_14-2
   .byte <MazePF1Data_15-2
   .byte <MazePF1Data_16-2
   .byte <MazePF1Data_17-2
   .byte <MazePF1Data_18-2
   .byte <MazePF1Data_19-2
   .byte <MazePF1Data_20-2
   .byte <MazePF1Data_21-2
   .byte <MazePF1Data_22-2
   .byte <MazePF1Data_23-2
   .byte <MazePF1Data_24-2
   .byte <MazePF1Data_25-2
   .byte <MazePF1Data_26-2
   .byte <MazePF1Data_27-2
   .byte <MazePF1Data_28-2
   .byte <MazePF1Data_29-2
   .byte <MazePF1Data_30-2
   .byte <MazePF1Data_31-2
   .byte <MazePF1Data_32-2
   .byte <MazePF1Data_33-2
   .byte <MazePF1Data_34-2
   .byte <MazePF1Data_35-2
   .byte <MazePF1Data_36-2
   .byte <MazePF1Data_37-2
   .byte <MazePF1Data_38-2
   .byte <MazePF1Data_39-2
   .byte <MazePF1Data_40-2
   .byte <MazePF1Data_41-2
   .byte <MazePF1Data_42-2
   .byte <MazePF1Data_43-2
   .byte <MazePF1Data_44-2
   .byte <MazePF1Data_45-2
   .byte <MazePF1Data_46-2
   .byte <MazePF1Data_47-2
   .byte <MazePF1Data_48-2
   .byte <MazePF1Data_49-2
   .byte <MazePF1Data_50-2
   .byte <MazePF1Data_51-2
   .byte <MazePF1Data_52-2
   .byte <MazePF1Data_53-2
   .byte <MazePF1Data_54-2
   .byte <MazePF1Data_55-2
   .byte <MazePF1Data_56-2
   .byte <MazePF1Data_57-2
   .byte <MazePF1Data_58-2
   .byte <MazePF1Data_59-2
   .byte <MazePF1Data_60-2
   .byte <MazePF1Data_61-2
   .byte <MazePF1Data_62-2
   .byte <MazePF1Data_63-2

MazePF1msb
   .byte >MazePF1Data_0
   .byte >MazePF1Data_1
   .byte >MazePF1Data_2
   .byte >MazePF1Data_3
   .byte >MazePF1Data_4
   .byte >MazePF1Data_5
   .byte >MazePF1Data_6
   .byte >MazePF1Data_7
   .byte >MazePF1Data_8
   .byte >MazePF1Data_9
   .byte >MazePF1Data_10
   .byte >MazePF1Data_11
   .byte >MazePF1Data_12
   .byte >MazePF1Data_13
   .byte >MazePF1Data_14
   .byte >MazePF1Data_15
   .byte >MazePF1Data_16
   .byte >MazePF1Data_17
   .byte >MazePF1Data_18
   .byte >MazePF1Data_19
   .byte >MazePF1Data_20
   .byte >MazePF1Data_21
   .byte >MazePF1Data_22
   .byte >MazePF1Data_23
   .byte >MazePF1Data_24
   .byte >MazePF1Data_25
   .byte >MazePF1Data_26
   .byte >MazePF1Data_27
   .byte >MazePF1Data_28
   .byte >MazePF1Data_29
   .byte >MazePF1Data_30
   .byte >MazePF1Data_31
   .byte >MazePF1Data_32
   .byte >MazePF1Data_33
   .byte >MazePF1Data_34
   .byte >MazePF1Data_35
   .byte >MazePF1Data_36
   .byte >MazePF1Data_37
   .byte >MazePF1Data_38
   .byte >MazePF1Data_39
   .byte >MazePF1Data_40
   .byte >MazePF1Data_41
   .byte >MazePF1Data_42
   .byte >MazePF1Data_43
   .byte >MazePF1Data_44
   .byte >MazePF1Data_45
   .byte >MazePF1Data_46
   .byte >MazePF1Data_47
   .byte >MazePF1Data_48
   .byte >MazePF1Data_49
   .byte >MazePF1Data_50
   .byte >MazePF1Data_51
   .byte >MazePF1Data_52
   .byte >MazePF1Data_53
   .byte >MazePF1Data_54
   .byte >MazePF1Data_55
   .byte >MazePF1Data_56
   .byte >MazePF1Data_57
   .byte >MazePF1Data_58
   .byte >MazePF1Data_59
   .byte >MazePF1Data_60
   .byte >MazePF1Data_61
   .byte >MazePF1Data_62
   .byte >MazePF1Data_63

MazePF2lsb
   .byte <MazePF2Data_0-2
   .byte <MazePF2Data_1-2
   .byte <MazePF2Data_2-2
   .byte <MazePF2Data_3-2
   .byte <MazePF2Data_4-2
   .byte <MazePF2Data_5-2
   .byte <MazePF2Data_6-2
   .byte <MazePF2Data_7-2
   .byte <MazePF2Data_8-2
   .byte <MazePF2Data_9-2
   .byte <MazePF2Data_10-2
   .byte <MazePF2Data_11-2
   .byte <MazePF2Data_12-2
   .byte <MazePF2Data_13-2
   .byte <MazePF2Data_14-2
   .byte <MazePF2Data_15-2
   .byte <MazePF2Data_16-2
   .byte <MazePF2Data_17-2
   .byte <MazePF2Data_18-2
   .byte <MazePF2Data_19-2
   .byte <MazePF2Data_20-2
   .byte <MazePF2Data_21-2
   .byte <MazePF2Data_22-2
   .byte <MazePF2Data_23-2
   .byte <MazePF2Data_24-2
   .byte <MazePF2Data_25-2
   .byte <MazePF2Data_26-2
   .byte <MazePF2Data_27-2
   .byte <MazePF2Data_28-2
   .byte <MazePF2Data_29-2
   .byte <MazePF2Data_30-2
   .byte <MazePF2Data_31-2
   .byte <MazePF2Data_32-2
   .byte <MazePF2Data_33-2
   .byte <MazePF2Data_34-2
   .byte <MazePF2Data_35-2
   .byte <MazePF2Data_36-2
   .byte <MazePF2Data_37-2
   .byte <MazePF2Data_38-2
   .byte <MazePF2Data_39-2
   .byte <MazePF2Data_40-2
   .byte <MazePF2Data_41-2
   .byte <MazePF2Data_42-2
   .byte <MazePF2Data_43-2
   .byte <MazePF2Data_44-2
   .byte <MazePF2Data_45-2
   .byte <MazePF2Data_46-2
   .byte <MazePF2Data_47-2
   .byte <MazePF2Data_48-2
   .byte <MazePF2Data_49-2
   .byte <MazePF2Data_50-2
   .byte <MazePF2Data_51-2
   .byte <MazePF2Data_52-2
   .byte <MazePF2Data_53-2
   .byte <MazePF2Data_54-2
   .byte <MazePF2Data_55-2
   .byte <MazePF2Data_56-2
   .byte <MazePF2Data_57-2
   .byte <MazePF2Data_58-2
   .byte <MazePF2Data_59-2
   .byte <MazePF2Data_60-2
   .byte <MazePF2Data_61-2
   .byte <MazePF2Data_62-2
   .byte <MazePF2Data_63-2

MazePF2msb
   .byte >MazePF2Data_0
   .byte >MazePF2Data_1
   .byte >MazePF2Data_2
   .byte >MazePF2Data_3
   .byte >MazePF2Data_4
   .byte >MazePF2Data_5
   .byte >MazePF2Data_6
   .byte >MazePF2Data_7
   .byte >MazePF2Data_8
   .byte >MazePF2Data_9
   .byte >MazePF2Data_10
   .byte >MazePF2Data_11
   .byte >MazePF2Data_12
   .byte >MazePF2Data_13
   .byte >MazePF2Data_14
   .byte >MazePF2Data_15
   .byte >MazePF2Data_16
   .byte >MazePF2Data_17
   .byte >MazePF2Data_18
   .byte >MazePF2Data_19
   .byte >MazePF2Data_20
   .byte >MazePF2Data_21
   .byte >MazePF2Data_22
   .byte >MazePF2Data_23
   .byte >MazePF2Data_24
   .byte >MazePF2Data_25
   .byte >MazePF2Data_26
   .byte >MazePF2Data_27
   .byte >MazePF2Data_28
   .byte >MazePF2Data_29
   .byte >MazePF2Data_30
   .byte >MazePF2Data_31
   .byte >MazePF2Data_32
   .byte >MazePF2Data_33
   .byte >MazePF2Data_34
   .byte >MazePF2Data_35
   .byte >MazePF2Data_36
   .byte >MazePF2Data_37
   .byte >MazePF2Data_38
   .byte >MazePF2Data_39
   .byte >MazePF2Data_40
   .byte >MazePF2Data_41
   .byte >MazePF2Data_42
   .byte >MazePF2Data_43
   .byte >MazePF2Data_44
   .byte >MazePF2Data_45
   .byte >MazePF2Data_46
   .byte >MazePF2Data_47
   .byte >MazePF2Data_48
   .byte >MazePF2Data_49
   .byte >MazePF2Data_50
   .byte >MazePF2Data_51
   .byte >MazePF2Data_52
   .byte >MazePF2Data_53
   .byte >MazePF2Data_54
   .byte >MazePF2Data_55
   .byte >MazePF2Data_56
   .byte >MazePF2Data_57
   .byte >MazePF2Data_58
   .byte >MazePF2Data_59
   .byte >MazePF2Data_60
   .byte >MazePF2Data_61
   .byte >MazePF2Data_62
   .byte >MazePF2Data_63

   org  $2E00
   rorg $FE00

;bugfix...keep these tables low!  Dead robots can cause a conflict at the end of the page!
RobotAnimationTableOffsets
StandingAnimationOffset
   .byte <StandingAnimation0-RobotGraphics
   .byte <StandingAnimation0-RobotGraphics
   .byte <StandingAnimation1-RobotGraphics
   .byte <StandingAnimation2-RobotGraphics
   .byte <StandingAnimation3-RobotGraphics
   .byte <StandingAnimation4-RobotGraphics
   .byte <StandingAnimation5-RobotGraphics
   .byte <StandingAnimation6-RobotGraphics
   .byte <StandingAnimation7-RobotGraphics
WalkingLeftAnimationOffset
   .byte <WalkingLeftAnimation0-RobotGraphics
   .byte <WalkingLeftAnimation1-RobotGraphics
   .byte <WalkingLeftAnimation1-RobotGraphics
WalkingRightAnimationOffset
   .byte <WalkingRightAnimation0-RobotGraphics
   .byte <WalkingRightAnimation1-RobotGraphics
   .byte <WalkingRightAnimation1-RobotGraphics
WalkingUpAnimationOffset
   .byte <WalkingUpAnimation0-RobotGraphics
   .byte <StandingAnimation0-RobotGraphics
   .byte <WalkingUpAnimation1-RobotGraphics
   .byte <StandingAnimation0-RobotGraphics
WalkingDownAnimationOffset
   .byte <StandingAnimation4-RobotGraphics
   .byte <WalkingDownAnimation1-RobotGraphics
   .byte <StandingAnimation4-RobotGraphics
   .byte <WalkingDownAnimation0-RobotGraphics
DeathAnimationOffset
   .byte <DeathAnimation0-RobotGraphics
   .byte <DeathAnimation1-RobotGraphics
   .byte <DeathAnimation2-RobotGraphics
   .byte <DeathAnimation2-RobotGraphics

RobotAnimationTable
   .byte <StandingAnimationOffset-RobotAnimationTableOffsets+1
   .byte <StandingAnimationOffset-RobotAnimationTableOffsets+2
   .byte <StandingAnimationOffset-RobotAnimationTableOffsets+3
   .byte <StandingAnimationOffset-RobotAnimationTableOffsets+4
   .byte <StandingAnimationOffset-RobotAnimationTableOffsets+5
   .byte <StandingAnimationOffset-RobotAnimationTableOffsets+6
   .byte <StandingAnimationOffset-RobotAnimationTableOffsets+7
   .byte <StandingAnimationOffset-RobotAnimationTableOffsets+8
   .byte <StandingAnimationOffset-RobotAnimationTableOffsets

   .byte <WalkingLeftAnimationOffset-RobotAnimationTableOffsets+1
   .byte <WalkingLeftAnimationOffset-RobotAnimationTableOffsets+2
   .byte <WalkingLeftAnimationOffset-RobotAnimationTableOffsets

   .byte <WalkingRightAnimationOffset-RobotAnimationTableOffsets+1
   .byte <WalkingRightAnimationOffset-RobotAnimationTableOffsets+2
   .byte <WalkingRightAnimationOffset-RobotAnimationTableOffsets

   .byte <WalkingUpAnimationOffset-RobotAnimationTableOffsets+1
   .byte <WalkingUpAnimationOffset-RobotAnimationTableOffsets+2
   .byte <WalkingUpAnimationOffset-RobotAnimationTableOffsets+3
   .byte <WalkingUpAnimationOffset-RobotAnimationTableOffsets

   .byte <WalkingDownAnimationOffset-RobotAnimationTableOffsets+1
   .byte <WalkingDownAnimationOffset-RobotAnimationTableOffsets+2
   .byte <WalkingDownAnimationOffset-RobotAnimationTableOffsets+3
   .byte <WalkingDownAnimationOffset-RobotAnimationTableOffsets


GameVariationTable
   .byte EXTRA_LIFE_1000                                 ;0
   .byte EXTRA_LIFE_1000                                 ;1
   .byte EXTRA_LIFE_1000                                 ;2
   .byte EXTRA_LIFE_1000|OTTO_REBOUND                    ;3
   .byte EXTRA_LIFE_1000|OTTO_REBOUND                    ;4
   .byte EXTRA_LIFE_1000|OTTO_INVINCIBLE                 ;5
   .byte EXTRA_LIFE_1000|OTTO_INVINCIBLE                 ;6
   .byte EXTRA_LIFE_2000                                 ;7
   .byte EXTRA_LIFE_2000                                 ;8
   .byte EXTRA_LIFE_2000|OTTO_REBOUND                    ;9
   .byte EXTRA_LIFE_2000|OTTO_REBOUND                    ;10
   .byte EXTRA_LIFE_2000|OTTO_INVINCIBLE                 ;11
   .byte EXTRA_LIFE_2000|OTTO_INVINCIBLE                 ;12
   .byte 0                                               ;13 no otto, no bonus
   .byte 0                                               ;14 no otto, no bonus
   .byte OTTO_REBOUND                                    ;15
   .byte OTTO_REBOUND                                    ;16
   .byte OTTO_INVINCIBLE                                 ;17
   .byte OTTO_INVINCIBLE                                 ;18
   .byte EXTRA_LIFE_1000|OTTO_INVINCIBLE|NON_SHOOTING    ;19
   .byte EXTRA_LIFE_1000|OTTO_INVINCIBLE|NON_SHOOTING    ;20
   .byte EXTRA_LIFE_1000|OTTO_REBOUND|NON_SHOOTING       ;21
   .byte EXTRA_LIFE_1000|OTTO_REBOUND|NON_SHOOTING       ;22
   .byte EXTRA_LIFE_1000|NON_SHOOTING                    ;23 children's game
   .byte EXTRA_LIFE_1000|NON_SHOOTING                    ;24 children's game

InitMissileXOffsetTable
   .byte 0, 7, 8, 0, 0, 0, 0, 0, 6, 6, 6

MissileVerticalLimitsTable
   .byte XMIN, XMIN+1, XMAX-1, XMAX


MarqueeShade
   .byte $04
   .byte $0A
   .byte $06
   .byte $02

RobotColorTable  ;duplicate table exists in the next bank (required)
   .byte YELLOW+10,RED_4+6,BLACK+12,LT_GREEN,RED_2+12
   .byte GREEN_BLUE,BROWN+12,PURPLE+8

PcolorTab2:
   .byte PLAYER_COLOR
   .byte PLAYER2_COLOR


;various subroutines...
;73
IncrementScore SUBROUTINE
;bugfix...
   ldy numberOfLives
   iny
   beq .leaveRoutine                ; 2 leave if game is over
Do_Score:
   ldy playerScore+2
   sty temp02                       ; save the thousands value of the score
   ldy #4
   sed
   clc
.incrementScoreLoop
   adc playerScore,y                ; increment score by accumulator
   sta playerScore,y
   lda #0
   dey
   dey
   bpl .incrementScoreLoop
   lda gameVariation                ; check for bonus life variation
   lsr
   lsr
   bcs .checkScorePass1000          ; check if score passed 1000 for extra life
   lsr
   bcc .leaveRoutine                ; leave if no bonus to be rewarded
   lda temp02                       ; load the saved thousands value (BCD)
   and #%00011111
   cmp #$19
   bne .leaveRoutine                ; didn't pass 2000 so no bonus life
.checkScorePass1000
   lda temp02                       ; load the saved thousands value (BCD)
   and #%00001111
   cmp #$09
   bne .leaveRoutine                ; didn't pass 1000 so no bonus life
   lda temp02                       ; load the saved thousands value (BCD)
   cmp playerScore+2                ; leave if it equals the value when coming
   beq .leaveRoutine                ; to routine
   clc
   lda gameState
   and #%01111100
   ora #%00000011
   sta gameState
   lda numberOfLives
   adc #01 ;BCD
   bcs .leaveRoutine                ; leave if rollover would set to zero
   sta numberOfLives
.leaveRoutine
   cld
   rts


;49
abort_routine
   sec
   cmp randomNumberMax
   bcc leaveRoutine
   lsr
leaveRoutine
   rts
NextRandom SUBROUTINE
   lda #$18                         ; set max tries
   sta MaxTries
   lda random
   asl                              ; shift random left (D7 into carry)
   eor random                       ; flip bits
   asl                              ; shift D6 of random into carry
   asl
   rol random+1                     ; rotate carry (D6 from random) into D0
   rol random                       ; rotate carry (D7 from random+1) into D0
   lda random+1
   and #%01111111                   ; mask D7 (0 <= a <= 127)
   sta temp01                       ; save value for later
.recomputeRandom
   dec MaxTries
   beq abort_routine
   clc
   adc temp02
   sec
   cmp randomNumberMax
   bcc leaveRoutine
   beq leaveRoutine
   lsr temp01                       ; divide temp01 by 2
   lda temp01                       ; and load accumulator with new value
   jmp .recomputeRandom



;28
DetermineDiv15Position
   ldy #0                           ; set to 0 for coarse value move
   clc
   adc #1                           ; increment x position by 1
   cmp #45                          ; compare the value with mid point
   bcc .skipXPosReduction
   ldy #3                           ; set to 3 for coarse value move
   sbc #45                          ; reduce x position by mid point
.skipXPosReduction
   sec
.divideBy15
   iny                              ; increment y each iteration for coarse
   sbc #15                          ; position loop
   bcs .divideBy15
   eor #$FF                         ; flip the bits of the remainder
   sbc #6                           ; subtract the value by 6
   asl                              ; shift value to upper nybbles for fine
   asl                              ; motion
   asl
   asl
   rts

   org  $2F00
   rorg $FF00

RobotMissileDelayTable
   .byte ROBOT_MISSILE_DELAY_0
   .byte ROBOT_MISSILE_DELAY_1
   .byte ROBOT_MISSILE_DELAY_2
   .byte ROBOT_MISSILE_DELAY_3
   .byte ROBOT_MISSILE_DELAY_4
   .byte ROBOT_MISSILE_DELAY_5
   .byte ROBOT_MISSILE_DELAY_6
   .byte ROBOT_MISSILE_DELAY_7

RobotMotionDelayTable
   .byte ROBOT_MOVE_DELAY_0
   .byte ROBOT_MOVE_DELAY_1
   .byte ROBOT_MOVE_DELAY_2
   .byte ROBOT_MOVE_DELAY_3
   .byte ROBOT_MOVE_DELAY_4
   .byte ROBOT_MOVE_DELAY_5
   .byte ROBOT_MOVE_DELAY_6
   .byte ROBOT_MOVE_DELAY_7

PlayerShootingAnimationTable
   .byte <PlayerFireHoriz-PlayerSprites
   .byte <PlayerFireUp-PlayerSprites
   .byte <PlayerFireDown-PlayerSprites
   .byte <PlayerFireHoriz-PlayerSprites

PlayerHorizAnimationTable
   .byte <PlayerStationary-PlayerSprites
   .byte <PlayerRunning0-PlayerSprites
   .byte <PlayerRunning1-PlayerSprites
   .byte <PlayerDeath-PlayerSprites

InitHorizontalPosition
   .byte XMAX_PLAYER / 2, XMAX_PLAYER / 2, XMIN + 6, XMAX_PLAYER - 7

InitVerticalPosition
   .byte YMIN + 8, 142
   .byte [(H_KERNEL / 2) - (H_PLAYER + 2)], [(H_KERNEL / 2) - (H_PLAYER + 2)]

InitRobotMissileYOffset
   .byte 0                          ; not moving
   .byte 7                          ; ROBOT_SHOOTING_RIGHT
   .byte 7                          ; ROBOT_SHOOTING_LEFT
   .byte 0                          ; ROBOT_SHOOTING_LEFT | ROBOT_SHOOTING_RIGHT
   .byte 6                          ; ROBOT_SHOOTING_DOWN
   .byte 6                          ; ROBOT_SHOOTING_DOWN | ROBOT_SHOOTING_RIGHT (OKAY)
   .byte 7                          ; ROBOT_SHOOTING_DOWN | ROBOT_SHOOTING_LEFT (OKAY)
   .byte 0                          ; south and left and right (IMPOSSIBLE)
   .byte 1                          ; ROBOT_SHOOTING_UP
   .byte 7                          ; ROBOT_SHOOTING_UP | ROBOT_SHOOTING_RIGHT
   .byte 7                          ; ROBOT_SHOOTING_UP | ROBOT_SHOOTING_LEFT (OKAY)

InitRobotMissileXOffset
   .byte 3                          ; not moving
   .byte 11                         ; ROBOT_SHOOTING_RIGHT
   .byte 3                          ; ROBOT_SHOOTING_LEFT
   .byte 3                          ; ROBOT_SHOOTING_LEFT | ROBOT_SHOOTING_RIGHT
   .byte 4                          ; ROBOT_SHOOTING_DOWN
   .byte 11                         ; ROBOT_SHOOTING_DOWN | ROBOT_SHOOTING_RIGHT (OKAY)
   .byte 3                          ; ROBOT_SHOOTING_DOWN | ROBOT_SHOOTING_LEFT (OKAY)
   .byte 3                          ; south and left and right (IMPOSSIBLE)
   .byte 4                          ; ROBOT_SHOOTING_UP
   .byte 10                         ; ROBOT_SHOOTING_UP | ROBOT_SHOOTING_RIGHT (OKAY 13 or 14)
   .byte 1                          ; ROBOT_SHOOTING_UP | ROBOT_SHOOTING_LEFT (OKAY)

VerticalPixelOffsets
   .byte 0, <-1, 1, 0, 0, <-1, 1, 0, 0, <-1, 1, 0 ;;, 0, 0, 0, 0 (last 4 values shared w/next)
HorizontalPixelOffsets
   .byte 0, 0, 0, 0, <-1, <-1, <-1, <-1, 1, 1, 1, 1, 0, 0, 0 ;;, 0 (last value shared w/next)
InitMissileYOffsetTable
   .byte 0, 2, 7, 0, 5, 5, 7, 0, 5, 5, 7

StartingLocationValues
   .byte PLAYER_ENTERING_SOUTH
   .byte PLAYER_ENTERING_NORTH
   .byte PLAYER_ENTERING_EAST
   .byte PLAYER_ENTERING_WEST

AttractModeColors
   .byte RED_3
   .byte BLACK+1
   .byte BROWN_2+2

MarqueeData:
   .byte #%11000000   ; Scanline 60
   .byte #%00100000   ; Scanline 56
   .byte #%10010000   ; Scanline 52
   .byte #%01010000   ; Scanline 48
   .byte #%01010000   ; Scanline 44
   .byte #%01010000   ; Scanline 40
   .byte #%01010000   ; Scanline 36
   .byte #%01010000   ; Scanline 32
   .byte #%01010000   ; Scanline 28
   .byte #%01010000   ; Scanline 24
   .byte #%01010000   ; Scanline 20
   .byte #%01010000   ; Scanline 16
   .byte #%01010000   ; Scanline 12
   .byte #%10010000   ; Scanline 8
   .byte #%00100000   ; Scanline 4
   .byte #%11000000   ; Scanline 0

   .byte #%11111111   ; Scanline 60
   .byte #%00000000   ; Scanline 56
   .byte #%11111111   ; Scanline 52
   .byte #%00000000   ; Scanline 48
   .byte #%11100011   ; Scanline 44
   .byte #%10010010   ; Scanline 40
   .byte #%10001010   ; Scanline 36
   .byte #%10001010   ; Scanline 32
   .byte #%10001010   ; Scanline 28
   .byte #%10110011   ; Scanline 24
   .byte #%10001010   ; Scanline 20
   .byte #%10001010   ; Scanline 16
   .byte #%00010010   ; Scanline 12
   .byte #%11100011   ; Scanline 8
   .byte #%00000000   ; Scanline 4
   .byte #%11111111   ; Scanline 0

   .byte #%11111111   ; Scanline 60
   .byte #%01000000   ; Scanline 56
   .byte #%11110011   ; Scanline 52
   .byte #%00100010   ; Scanline 48
   .byte #%01010010   ; Scanline 44
   .byte #%01010010   ; Scanline 40
   .byte #%10001010   ; Scanline 36
   .byte #%10001010   ; Scanline 32
   .byte #%00000110   ; Scanline 28
   .byte #%00001010   ; Scanline 24
   .byte #%00010010   ; Scanline 20
   .byte #%00010010   ; Scanline 16
   .byte #%00001000   ; Scanline 12
   .byte #%11000111   ; Scanline 8
   .byte #%00000000   ; Scanline 4
   .byte #%11111111   ; Scanline 0

   .byte #%00000000   ; Scanline 60
   .byte #%00000000   ; Scanline 56
   .byte #%11110000   ; Scanline 52
   .byte #%00000000   ; Scanline 48
   .byte #%00000000   ; Scanline 44
   .byte #%00000000   ; Scanline 40
   .byte #%00000000   ; Scanline 36
   .byte #%00000000   ; Scanline 32
   .byte #%00010000   ; Scanline 28
   .byte #%00010000   ; Scanline 24
   .byte #%00100000   ; Scanline 20
   .byte #%00100000   ; Scanline 16
   .byte #%01000000   ; Scanline 12
   .byte #%00110000   ; Scanline 8
   .byte #%00000000   ; Scanline 4
   .byte #%11110000   ; Scanline 0

   .byte #%00000000   ; Scanline 60
   .byte #%00000000   ; Scanline 56
   .byte #%11111111   ; Scanline 52
   .byte #%00000001   ; Scanline 48
   .byte #%11010010   ; Scanline 44
   .byte #%10010010   ; Scanline 40
   .byte #%10010100   ; Scanline 36
   .byte #%10010100   ; Scanline 32
   .byte #%10011000   ; Scanline 28
   .byte #%11010100   ; Scanline 24
   .byte #%10010010   ; Scanline 20
   .byte #%10010010   ; Scanline 16
   .byte #%10000100   ; Scanline 12
   .byte #%11111000   ; Scanline 8
   .byte #%00000000   ; Scanline 4
   .byte #%11111111   ; Scanline 0

   .byte #%00111110   ; Scanline 60
   .byte #%01000001   ; Scanline 56
   .byte #%10011111   ; Scanline 52
   .byte #%10100000   ; Scanline 48
   .byte #%10101001   ; Scanline 44
   .byte #%10101001   ; Scanline 40
   .byte #%10100101   ; Scanline 36
   .byte #%10100101   ; Scanline 32
   .byte #%10100011   ; Scanline 28
   .byte #%10100011   ; Scanline 24
   .byte #%10100101   ; Scanline 20
   .byte #%10100101   ; Scanline 16
   .byte #%10101001   ; Scanline 12
   .byte #%10010001   ; Scanline 8
   .byte #%01000000   ; Scanline 4
   .byte #%00111111   ; Scanline 0

Screen_PF0
   .byte #%00100000   ; Scanline 4
   .byte #%00100000   ; Scanline 3
   .byte #%00100000   ; Scanline 2
   .byte #%00100000   ; Scanline 1
   .byte #%11110000   ; Scanline 0

Screen_PF1
   .byte #%00101000   ; Scanline 4
   .byte #%01010101   ; Scanline 3
   .byte #%01010101   ; Scanline 2
   .byte #%01000101   ; Scanline 1
   .byte #%01000100   ; Scanline 0

Screen_PF2
   .byte #%00100001   ; Scanline 4
   .byte #%00100010   ; Scanline 3
   .byte #%01101010   ; Scanline 2
   .byte #%10100010   ; Scanline 1
   .byte #%01100001   ; Scanline 0

Screen_PF3
   .byte #%11100000   ; Scanline 4
   .byte #%00100000   ; Scanline 3
   .byte #%00100000   ; Scanline 2
   .byte #%00100000   ; Scanline 1
   .byte #%00100000   ; Scanline 0

Screen_PF4
   .byte #%01010010   ; Scanline 4
   .byte #%01010010   ; Scanline 3
   .byte #%01110010   ; Scanline 2
   .byte #%01010101   ; Scanline 1
   .byte #%00100101   ; Scanline 0

Screen_PF5
   .byte #%10101110   ; Scanline 4
   .byte #%10100010   ; Scanline 3
   .byte #%01100110   ; Scanline 2
   .byte #%10100010   ; Scanline 1
   .byte #%01101110   ; Scanline 0

MarqueeColor
   .byte $20
   .byte $20
   .byte $20
   .byte $20
   .byte $20
   .byte $20
   .byte $20
   .byte $20
   .byte $20
   .byte $20
   .byte $20
   .byte $20
   .byte $20
   .byte $20
   .byte $20
   .byte $20

   IF COMPILE_VERSION = NTSC

ScreenShade
   .byte $32
   .byte $34
   .byte $36
   .byte $38
   .byte $3A

   ELSE

ScreenShade
   .byte $42
   .byte $44
   .byte $46
   .byte $48
   .byte $4A

   ENDIF

   org  $2FF6
   rorg $FFF6
   .byte 0,0,0
Start2
   jmp ColdStart ;hotspot JMP...automatically sets second bank
   .word Start2,Start2
